@@ -18,6 +18,8 @@ from collections import OrderedDict
 from pyaedt import settings
 from pyaedt.application.Design import Design
 from pyaedt.application.JobManager import update_hpc_option
+from pyaedt.application.Variables import Variable
+from pyaedt.application.Variables import decompose_variable_value
 from pyaedt.generic.constants import AXIS
 from pyaedt.generic.constants import GRAVITY
 from pyaedt.generic.constants import PLANE
@@ -39,6 +41,10 @@ from pyaedt.modules.DesignXPloration import ParametricSetups
 from pyaedt.modules.MaterialLib import Materials
 from pyaedt.modules.SetupTemplates import SetupProps
 from pyaedt.modules.SolveSetup import Setup
+from pyaedt.modules.SolveSetup import SetupHFSS
+from pyaedt.modules.SolveSetup import SetupHFSSAuto
+from pyaedt.modules.SolveSetup import SetupMaxwell
+from pyaedt.modules.SolveSetup import SetupSBR
 
 
 class Analysis(Design, object):
@@ -248,6 +254,7 @@ class Analysis(Design, object):
 
         .. deprecated:: 0.4.8
            Use :attr:`GRAVITY` instead.
+
         Returns
         -------
         tuple
@@ -622,7 +629,20 @@ class Analysis(Design, object):
                 return [""]
 
     @pyaedt_function_handler()
-    def export_results(self, analyze=False, export_folder=None):
+    def export_results(
+        self,
+        analyze=False,
+        export_folder=None,
+        matrix_name=None,
+        matrix_type="S",
+        touchstone_format="MagPhase",
+        touchstone_number_precision=15,
+        length="1meter",
+        impedance=50,
+        use_export_freq=True,
+        include_gamma_comment=True,
+        support_non_standard_touchstone_extension=False,
+    ):
         """Export all available reports to a file, including sNp, profile, and convergence.
 
         Parameters
@@ -632,6 +652,27 @@ class Analysis(Design, object):
         export_folder : str, optional
             Full path to the project folder. The default is ``None``, in which case the
             working directory is used.
+        matrix_name : str, optional
+            Matrix to specify to export touchstone file. The default is ``None``, in which case
+            the first matrix is taken.
+        matrix_type : str, optional
+            Type of matrix to export. The default is ``S``.
+            Available values are ``S``, ``Y``, ``Z``.
+        touchstone_format : str, optional
+            Touchstone format. The default is ``MagPahse``.
+            Available values are: ``MagPahse``, ``DbPhase``, ``RealImag``.
+        length : str, optional
+            Length of the model to export. The default is ``1meter``.
+        impedance : float, optional
+            Real impedance value in ohms, for renormalization. The default is ``50``.
+        touchstone_number_precision : int, optional
+            Touchstone number of digits precision. The default is ``15``.
+        use_export_freq : bool, optional
+            Specifies whether to use export frequencies. The default is ``True``.
+        include_gamma_comment : bool, optional
+            Specifies whether to include Gamma and Impedance comments. The default is ``True``.
+        support_non_standard_touchstone_extension : bool, optional
+            Specifies whether to include Gamma and Impedance comments. The default is ``True``.
 
         Returns
         -------
@@ -652,19 +693,18 @@ class Analysis(Design, object):
             export_folder = self.working_directory
         if analyze:
             self.analyze_all()
-        if self.design_type == "Circuit Design":
-            setups = self.oanalysis.GetAllSolutionSetups()
+        # excitations
+        if self.design_type == "HFSS3DLayout" or self.design_type == "HFSS 3D Layout Design":
+            excitations = len(self.oexcitation.GetAllPortsList())
+        elif self.design_type == "2D Extractor":
+            excitations = self.oboundary.GetNumExcitations("SignalLine")
+        elif self.design_type == "Q3D Extractor":
+            excitations = self.oboundary.GetNumExcitations("Source")
+        elif self.design_type == "Circuit Design":
             excitations = len(self.excitations)
         else:
-            setups = self.oanalysis.GetSetups()
-            if self.design_type == "HFSS3DLayout" or self.design_type == "HFSS 3D Layout Design":
-                excitations = len(self.oexcitation.GetAllPortsList())
-            elif self.design_type == "2D Extractor":
-                excitations = self.oboundary.GetNumExcitations("SignalLine")
-            elif self.design_type == "Q3D Extractor":
-                excitations = self.oboundary.GetNumExcitations("Source")
-            else:
-                excitations = self.oboundary.GetNumExcitations()
+            excitations = self.oboundary.GetNumExcitations()
+        # reports
         reportnames = self.post.oreportsetup.GetAllReportNames()
         for report_name in reportnames:
             name_no_space = report_name.replace(" ", "_")
@@ -679,57 +719,144 @@ class Analysis(Design, object):
                 pass
             exported_files.append(export_path)
 
+        if touchstone_format == "MagPhase":
+            touchstone_format_value = 0
+        elif touchstone_format == "RealImag":
+            touchstone_format_value = 1
+        elif touchstone_format == "DbPhase":
+            touchstone_format_value = 2
+        else:
+            self.logger.warning("Touchstone format not valid. ``MagPhase`` will be set as default")
+            touchstone_format_value = 0
+
+        # setups
+        setups = self.setups
         for s in setups:
             if self.design_type == "Circuit Design":
                 exported_files.append(self.browse_log_file(export_folder))
             else:
-                sweeps = self.oanalysis.GetSweeps(s)
-                if len(sweeps) == 0:
-                    sweeps = ["LastAdaptive"]
-                else:
-                    pass
-                for sweep in sweeps:
-                    variation_array = self.list_of_variations(s, sweep)
-                    if not variation_array:
-                        variation_array = [""]
-                    varCount = 0
-                    for variation in variation_array:
-                        varCount += 1
-                        export_path = os.path.join(export_folder, "{0}_{1}.prof".format(self.project_name, varCount))
-                        result = self.export_profile(s, variation, export_path)
-                        if result:
-                            exported_files.append(export_path)
-                        export_path = os.path.join(export_folder, "{0}_{1}.conv".format(self.project_name, varCount))
-                        self.logger.info("Export Convergence: %s", export_path)
-                        result = self.export_convergence(s, variation, export_path)
-                        if result:
-                            exported_files.append(export_path)
-                        if self.design_type in ["HFSS3DLayout", "HFSS 3D Layout Design", "HFSS"]:
-                            try:
-                                export_path = os.path.join(
-                                    export_folder, "{0}_{1}.s{2}p".format(self.project_name, varCount, excitations)
-                                )
-                                self.logger.info("Export SnP: {}".format(export_path))
-                                self.osolution.ExportNetworkData(
-                                    variation,
-                                    ["{0}:{1}".format(s, sweep)],
-                                    3,
-                                    export_path,
-                                    ["All"],
-                                    True,
-                                    50,
-                                    "S",
-                                    -1,
-                                    0,
-                                    15,
-                                    True,
-                                    False,
-                                    False,
-                                )
+                if s.is_solved:
+                    setup_name = s.name
+                    sweeps = s.sweeps
+                    if len(sweeps) == 0:
+                        sweeps = ["LastAdaptive"]
+                    # variations
+                    variations_list = []
+                    if not self.available_variations.nominal_w_values_dict:
+                        variations_list.append("")
+                    else:
+                        for x in range(0, len(self.available_variations.nominal_w_values_dict)):
+                            variation = "{}='{}'".format(
+                                list(self.available_variations.nominal_w_values_dict.keys())[x],
+                                list(self.available_variations.nominal_w_values_dict.values())[x],
+                            )
+                            variations_list.append(variation)
+                    # sweeps
+                    for sweep in sweeps:
+                        if sweep == "LastAdaptive":
+                            sweep_name = sweep
+                        else:
+                            sweep_name = sweep.name
+                        varCount = 0
+                        for variation in variations_list:
+                            varCount += 1
+                            export_path = os.path.join(
+                                export_folder, "{0}_{1}.prof".format(self.project_name, varCount)
+                            )
+                            result = self.export_profile(setup_name, variation, export_path)
+                            if result:
                                 exported_files.append(export_path)
-                                self.logger.info("Exported Touchstone: %s", export_path)
-                            except:
-                                self.logger.warning("Export SnP failed: no solutions found")
+                            export_path = os.path.join(
+                                export_folder, "{0}_{1}.conv".format(self.project_name, varCount)
+                            )
+                            self.logger.info("Export Convergence: %s", export_path)
+                            result = self.export_convergence(setup_name, variation, export_path)
+                            if result:
+                                exported_files.append(export_path)
+
+                            export_path = os.path.join(
+                                export_folder, "{0}_{1}.s{2}p".format(self.project_name, varCount, excitations)
+                            )
+                            self.logger.info("Export SnP: {}".format(export_path))
+
+                            if self.design_type in ["2D Extractor", "Q3D Extractor"]:
+                                freq_model_unit = decompose_variable_value(s.props["AdaptiveFreq"])[1]
+                                freq_array = []
+                                if sweep == "LastAdaptive":
+                                    # If sweep is Last Adaptive for Q2D and Q3D
+                                    # the default range freq is [10MHz, 100MHz, step: 10MHz]
+                                    # Q2D and Q3D don't accept in ExportNetworkData ["All"]
+                                    # as frequency array
+                                    freq_range = range(10, 100, 10)
+                                    for freq in freq_range:
+                                        v = Variable("{}{}".format(freq, "MHz"))
+                                        freq_array.append(v.rescale_to("Hz").numeric_value)
+                                else:
+                                    for freq in sweep.frequencies:
+                                        v = Variable("{}{}".format("{0:.12f}".format(freq), freq_model_unit))
+                                        freq_array.append(v.rescale_to("Hz").numeric_value)
+
+                            # export touchstone as .sNp file
+                            if self.design_type in ["HFSS3DLayout", "HFSS 3D Layout Design", "HFSS"]:
+                                try:
+                                    self.logger.info("Export SnP: {}".format(export_path))
+                                    self.osolution.ExportNetworkData(
+                                        variation,
+                                        ["{0}:{1}".format(setup_name, sweep_name)],
+                                        3,
+                                        export_path,
+                                        ["All"],
+                                        True,
+                                        impedance,
+                                        matrix_type,
+                                        -1,
+                                        touchstone_format_value,
+                                        touchstone_number_precision,
+                                        use_export_freq,
+                                        include_gamma_comment,
+                                        support_non_standard_touchstone_extension,
+                                    )
+                                    exported_files.append(export_path)
+                                    self.logger.info("Exported Touchstone: %s", export_path)
+                                except:
+                                    self.logger.warning("Export SnP failed: no solutions found")
+                            elif self.design_type == "2D Extractor":
+                                try:
+                                    self.logger.info("Export SnP: {}".format(export_path))
+                                    self.odesign.ExportNetworkData(
+                                        variation,
+                                        "{0}:{1}".format(setup_name, sweep_name),
+                                        export_path,
+                                        matrix_name,
+                                        impedance,
+                                        freq_array,
+                                        touchstone_format,
+                                        length,
+                                        0,
+                                    )
+                                    exported_files.append(export_path)
+                                    self.logger.info("Exported Touchstone: %s", export_path)
+                                except:
+                                    self.logger.warning("Export SnP failed: no solutions found")
+                            elif self.design_type == "Q3D Extractor":
+                                try:
+                                    self.logger.info("Export SnP: {}".format(export_path))
+                                    self.odesign.ExportNetworkData(
+                                        variation,
+                                        "{0}:{1}".format(setup_name, sweep_name),
+                                        export_path,
+                                        matrix_name,
+                                        impedance,
+                                        freq_array,
+                                        touchstone_format,
+                                        0,
+                                    )
+                                    exported_files.append(export_path)
+                                    self.logger.info("Exported Touchstone: %s", export_path)
+                                except:
+                                    self.logger.warning("Export SnP failed: no solutions found")
+                else:
+                    self.logger.warning("Setup is not solved. To export results please analyze setup first.")
         return exported_files
 
     @pyaedt_function_handler()
@@ -1171,7 +1298,7 @@ class Analysis(Design, object):
 
         Returns
         -------
-        :class:`pyaedt.modules.SolveSetup.Setup`
+        :class:`pyaedt.modules.SolveSetup.SetupHFSS` or :class:`pyaedt.modules.SolveSetup.SetupHFSSAuto`
 
         References
         ----------
@@ -1196,9 +1323,22 @@ class Analysis(Design, object):
         >>> setup1.props["SbrRangeDopplerVelocityMax"] = "30m_per_sec"
         >>> setup1.props["DopplerRayDensityPerWavelength"] = "0.2"
         >>> setup1.props["MaxNumberOfBounces"] = "3"
-        >>> setup1.update()
         ...
-        pyaedt info: Sweep was created correctly.
+        pyaedt INFO: Sweep was created correctly.
+        >>> setup1.add_subrange("LinearStep", 1, 10, 0.1, clear=True)
+        >>> setup1.add_subrange("LinearCount", 10, 20, 10, clear=False)
+
+
+        Create a setup for Q3d and add a sweep on it.
+
+        >>> import pyaedt
+        >>> q = pyaedt.Q3d()
+        >>> setup1 = q.create_setup(props={"AdaptiveFreq": "100MHz"})
+        >>> sw1 = setup1.add_sweep()
+        >>> sw1.props["RangeStart"] = "1MHz"
+        >>> sw1.props["RangeEnd"] = "100MHz"
+        >>> sw1.props["RangeStep"] = "5MHz"
+        >>> sw1.update()
         """
         if props is None:
             props = {}
@@ -1206,7 +1346,15 @@ class Analysis(Design, object):
         if setuptype is None:
             setuptype = self.design_solutions.default_setup
         name = self.generate_unique_setup_name(setupname)
-        setup = Setup(self, setuptype, name)
+        if setuptype == 0:
+            setup = SetupHFSSAuto(self, setuptype, name)
+        elif setuptype == 4:
+            setup = SetupSBR(self, setuptype, name)
+        elif setuptype in [5, 6, 7, 8, 9, 10]:
+            setup = SetupMaxwell(self, setuptype, name)
+        else:
+            setup = SetupHFSS(self, setuptype, name)
+
         if self.design_type == "HFSS":
             if not self.excitations and "MaxDeltaS" in setup.props:
                 new_dict = OrderedDict()
@@ -1219,45 +1367,48 @@ class Analysis(Design, object):
                 setup.props = SetupProps(setup, new_dict)
                 setup.auto_update = True
 
-            for boundary in self.boundaries:
-                if "Type" in boundary.props.keys() and boundary.props["Type"] == "SBR+":
-                    setup.auto_update = False
-                    user_domain = None
-                    if props:
-                        if "RadiationSetup" in props:
-                            user_domain = props["RadiationSetup"]
-                    if self.field_setups:
-                        for field_setup in self.field_setups:
-                            if user_domain and user_domain in field_setup.name:
-                                domain = user_domain
-                                break
-                        if not user_domain and self.field_setups:
-                            domain = self.field_setups[0].name
-                    elif user_domain:
-                        domain = user_domain
-                    else:
-                        self.logger.error("Field Observation Domain not defined")
-                        return False
+            if self.solution_type == "SBR+":
+                setup.auto_update = False
+                default_sbr_setup = {
+                    "RayDensityPerWavelength": 4,
+                    "MaxNumberOfBounces": 5,
+                    "EnableCWRays": False,
+                    "EnableSBRSelfCoupling": False,
+                    "UseSBRAdvOptionsGOBlockage": False,
+                    "UseSBRAdvOptionsWedges": False,
+                    "PTDUTDSimulationSettings": "None",
+                    "SkipSBRSolveDuringAdaptivePasses": True,
+                    "UseSBREnhancedRadiatedPowerCalculation": False,
+                    "AdaptFEBIWithRadiation": False,
+                }
+                user_domain = None
+                if props:
+                    if "RadiationSetup" in props:
+                        user_domain = props["RadiationSetup"]
+                if self.field_setups:
+                    for field_setup in self.field_setups:
+                        if user_domain and user_domain in field_setup.name:
+                            domain = user_domain
+                            default_sbr_setup["RadiationSetup"] = domain
+                            break
+                    if not user_domain and self.field_setups:
+                        domain = self.field_setups[0].name
+                        default_sbr_setup["RadiationSetup"] = domain
 
-                    default_sbr_setup = {
-                        "RayDensityPerWavelength": 4,
-                        "MaxNumberOfBounces": 5,
-                        "EnableCWRays": False,
-                        "RadiationSetup": domain,
-                        "EnableSBRSelfCoupling": False,
-                        "UseSBRAdvOptionsGOBlockage": False,
-                        "UseSBRAdvOptionsWedges": False,
-                        "PTDUTDSimulationSettings": "None",
-                        "SkipSBRSolveDuringAdaptivePasses": True,
-                        "UseSBREnhancedRadiatedPowerCalculation": False,
-                        "AdaptFEBIWithRadiation": False,
-                    }
-                    new_dict = setup.props
-                    for k, v in default_sbr_setup.items():
-                        new_dict[k] = v
-                    setup.props = SetupProps(setup, new_dict)
-                    setup.auto_update = True
-                    break
+                elif user_domain:
+                    domain = user_domain
+                    default_sbr_setup["RadiationSetup"] = domain
+
+                else:
+                    self.logger.warning("Field Observation Domain not defined")
+                    default_sbr_setup["RadiationSetup"] = ""
+                    default_sbr_setup["ComputeFarFields"] = False
+
+                new_dict = setup.props
+                for k, v in default_sbr_setup.items():
+                    new_dict[k] = v
+                setup.props = SetupProps(setup, new_dict)
+                setup.auto_update = True
 
         setup.create()
         if props:
@@ -1297,7 +1448,7 @@ class Analysis(Design, object):
         >>> setup1 = hfss.create_setup(setupname='Setup1')
         >>> hfss.delete_setup(setupname='Setup1')
         ...
-        pyaedt info: Sweep was deleted correctly.
+        pyaedt INFO: Sweep was deleted correctly.
         """
         if setupname in self.existing_analysis_setups:
             self.oanalysis.DeleteSetups([setupname])
@@ -1348,9 +1499,19 @@ class Analysis(Design, object):
         :class:`pyaedt.modules.SolveSetup.Setup`
 
         """
-
         setuptype = self.design_solutions.default_setup
-        setup = Setup(self, setuptype, setupname, isnewsetup=False)
+
+        if self.solution_type == "SBR+":
+            setuptype = 4
+            setup = SetupSBR(self, setuptype, setupname, isnewsetup=False)
+        elif self.design_type in ["Q3D Extractor", "2D Extractor", "HFSS"]:
+            setup = SetupHFSS(self, setuptype, setupname, isnewsetup=False)
+            if setup.props and setup.props.get("SetupType", "") == "HfssDrivenAuto":
+                setup = SetupHFSSAuto(self, 0, setupname, isnewsetup=False)
+        elif self.design_type in ["Maxwell 2D", "Maxwell 3D"]:
+            setup = SetupMaxwell(self, setuptype, setupname, isnewsetup=False)
+        else:
+            setup = Setup(self, setuptype, setupname, isnewsetup=False)
         if setup.props:
             self.analysis_setup = setupname
         return setup
@@ -1900,7 +2061,7 @@ class Analysis(Design, object):
         width : int, optional
             Column width in exported .txt file.
         precision : int, optional
-            Decimal precision number in exported *.txt file.
+            Decimal precision number in exported \\*.txt file.
         is_exponential : bool, optional
             Whether the format number is exponential or not.
         setup_name : str, optional
