@@ -3,14 +3,11 @@
 This module is implicitily loaded in HFSS 3D Layout when launched.
 
 """
-import datetime
 import gc
-import logging
 import os
 import re
 import shutil
 import sys
-import tempfile
 import time
 import traceback
 import warnings
@@ -23,23 +20,23 @@ except ImportError:  # pragma: no cover
         warnings.warn("PythonNET is needed to run PyAEDT.")
     elif sys.version[0] == 3 and sys.version[1] < 7:
         warnings.warn("EDB requires Linux Python 3.7 or later.")
+from pyaedt import pyaedt_logger
 from pyaedt import settings
-from pyaedt.aedt_logger import AedtLogger
 from pyaedt.edb_core import Components
 from pyaedt.edb_core import EdbHfss
 from pyaedt.edb_core import EdbLayout
 from pyaedt.edb_core import EdbNets
-from pyaedt.edb_core import EdbPadstacks
 from pyaedt.edb_core import EdbSiwave
 from pyaedt.edb_core import EdbStackup
-from pyaedt.edb_core.EDB_Data import EdbBuilder
-from pyaedt.edb_core.EDB_Data import SimulationConfiguration
+from pyaedt.edb_core.edb_data.edb_builder import EdbBuilder
+from pyaedt.edb_core.edb_data.simulation_configuration import SimulationConfiguration
+from pyaedt.edb_core.edb_data.sources import SourceType
 from pyaedt.edb_core.general import convert_py_list_to_net_list
 from pyaedt.edb_core.materials import Materials
+from pyaedt.edb_core.padstack import EdbPadstacks
 from pyaedt.edb_core.stackup import Stackup
 from pyaedt.generic.constants import CutoutSubdesignType
 from pyaedt.generic.constants import SolverType
-from pyaedt.generic.constants import SourceType
 from pyaedt.generic.general_methods import env_path
 from pyaedt.generic.general_methods import env_path_student
 from pyaedt.generic.general_methods import env_value
@@ -131,23 +128,8 @@ class Edb(object):
         if edb_initialized:
             self.oproject = oproject
             self._main = sys.modules["__main__"]
-            if isaedtowned and "aedt_logger" in dir(sys.modules["__main__"]):
-                self._logger = self._main.aedt_logger
-            else:
-                if not edbpath or not os.path.exists(os.path.dirname(edbpath)):
-                    project_dir = tempfile.gettempdir()
-                else:
-                    project_dir = os.path.dirname(edbpath)
-                if settings.logger_file_path:
-                    logfile = settings.logger_file_path
-                else:
-                    logfile = os.path.join(
-                        project_dir, "pyaedt{}.log".format(datetime.datetime.now().strftime("%Y%m%d_%H%M%S"))
-                    )
-                self._logger = AedtLogger(filename=logfile, level=logging.DEBUG)
-                self._logger.info("Logger started on %s", logfile)
-                self._main.aedt_logger = self._logger
-
+            self._global_logger = pyaedt_logger
+            self._logger = pyaedt_logger
             self.student_version = student_version
             self.logger.info("Logger is initialized in EDB.")
             if not edbversion:
@@ -176,18 +158,30 @@ class Edb(object):
                     edbpath = os.path.join(edbpath, generate_unique_name("layout") + ".aedb")
                 self.logger.info("No EDB is provided. Creating a new EDB {}.".format(edbpath))
             self.edbpath = edbpath
+            self.log_name = None
+            if edbpath:
+                self.log_name = os.path.join(
+                    os.path.dirname(edbpath), "pyaedt_" + os.path.splitext(os.path.split(edbpath)[-1])[0] + ".log"
+                )
+
             if isaedtowned and (inside_desktop or settings.remote_api):
                 self.open_edb_inside_aedt()
             elif edbpath[-3:] in ["brd", "gds", "xml", "dxf", "tgz"]:
                 self.edbpath = edbpath[:-4] + ".aedb"
                 working_dir = os.path.dirname(edbpath)
                 self.import_layout_pcb(edbpath, working_dir, use_ppe=use_ppe)
+                if settings.enable_local_log_file and self.log_name:
+                    self._logger = self._global_logger.add_file_logger(self.log_name, "Edb")
                 self.logger.info("EDB %s was created correctly from %s file.", self.edbpath, edbpath[-2:])
             elif not os.path.exists(os.path.join(self.edbpath, "edb.def")):
                 self.create_edb()
+                if settings.enable_local_log_file and self.log_name:
+                    self._logger = self._global_logger.add_file_logger(self.log_name, "Edb")
                 self.logger.info("EDB %s was created correctly.", self.edbpath)
             elif ".aedb" in edbpath:
                 self.edbpath = edbpath
+                if settings.enable_local_log_file and self.log_name:
+                    self._logger = self._global_logger.add_file_logger(self.log_name, "Edb")
                 self.open_edb()
             if self.builder:
                 self.logger.info("EDB was initialized.")
@@ -621,7 +615,8 @@ class Edb(object):
         """Core stackup.
 
         .. deprecated:: 0.6.5
-        There is no need to use core_stackup anymore. You can instantiate new class stackup directly from edb class .
+            There is no need to use the ``core_stackup`` property anymore.
+            You can instantiate a new ``stackup`` class directly from the ``Edb`` class.
         """
         mess = "`core_stackup` is deprecated.\n"
         mess += " Use `app.stackup` directly to instantiate new stackup methods."
@@ -689,15 +684,14 @@ class Edb(object):
 
     @property
     def pins(self):
-        """Pins.
+        """EDBPadstackInstance of Component.
 
         Returns
         -------
-        list
-            List of all pins.
+        dic[str, :class:`pyaedt.edb_core.edb_data.padstacks.EDBPadstackInstance`]
+            Dictionary of EDBPadstackInstance Components.
         """
-
-        pins = []
+        pins = {}
         if self.core_components:
             for el in self.core_components.components:
                 comp = self.edb.Cell.Hierarchy.Component.FindByName(self.active_layout, el)
@@ -706,7 +700,8 @@ class Edb(object):
                     for p in comp.LayoutObjs
                     if p.GetObjType() == self.edb.Cell.LayoutObjType.PadstackInstance and p.IsLayoutPin()
                 ]
-                pins += temp
+                for p in temp:
+                    pins[p.GetId()] = EDBPadstackInstance(p, self)
         return pins
 
     class Boundaries:
@@ -828,6 +823,9 @@ class Edb(object):
 
         """
         self._db.Close()
+        if self.log_name:
+            self._global_logger.remove_file_logger(os.path.split(self.log_name)[-1])
+            self._logger = self._global_logger
         time.sleep(2)
         start_time = time.time()
         self._wait_for_file_release()
@@ -870,6 +868,16 @@ class Edb(object):
 
         """
         self._db.SaveAs(fname)
+        self.edbpath = self._db.GetDirectory()
+        if self.log_name:
+            self._global_logger.remove_file_logger(os.path.split(self.log_name)[-1])
+            self._logger = self._global_logger
+
+        self.log_name = os.path.join(
+            os.path.dirname(fname), "pyaedt_" + os.path.splitext(os.path.split(fname)[-1])[0] + ".log"
+        )
+        if settings.enable_local_log_file:
+            self._logger = self._global_logger.add_file_logger(self.log_name, "Edb")
         return True
 
     @pyaedt_function_handler()
@@ -989,7 +997,7 @@ class Edb(object):
         open_cutout_at_end : bool, optional
             Whether to open the cutout at the end. The default
             is ``True``.
-        simulation_setup : EDB_Data.SimulationConfiguration object, optional
+        simulation_setup : edb_data.simulation_configuration.SimulationConfiguration object, optional
             Simulation setup to use to overwrite the other parameters. The default is ``None``.
 
         Returns
@@ -1072,6 +1080,7 @@ class Edb(object):
                 self._active_cell = list(self._db.TopCircuitCells)[0]
                 dllpath = os.path.join(os.path.dirname(__file__), "dlls", "EDBLib")
                 self.builder = EdbBuilder(self.edbutils, self._db, self._active_cell)
+                self.edbpath = self._db.GetDirectory()
                 self._init_objects()
             else:
                 db2.Close()
@@ -1163,6 +1172,7 @@ class Edb(object):
         open_cutout_at_end=True,
         nets_to_include=None,
         include_partial_instances=False,
+        keep_voids=True,
     ):
         """Create a cutout on a specified shape and save it to a new AEDB file.
 
@@ -1183,6 +1193,9 @@ class Edb(object):
         include_partial_instances : bool, optional
             Whether to include padstack instances that have bounding boxes intersecting with point list polygons.
             This operation may slow down the cutout export.
+        keep_voids : bool
+            Boolean used for keep or not the voids intersecting the polygon used for clipping the layout.
+            Default value is ``True``, ``False`` will remove the voids.
 
         Returns
         -------
@@ -1221,25 +1234,26 @@ class Edb(object):
                     _ref_nets.append(self.core_nets.nets[_ref].net_object)
             else:
                 _ref_nets.append(self.core_nets.nets[_ref].net_object)  # pragma: no cover
-        voids = [p for p in self.core_primitives.circles if p.is_void]
-        voids2 = [p for p in self.core_primitives.polygons if p.is_void]
-        voids.extend(voids2)
+        if keep_voids:
+            voids = [p for p in self.core_primitives.circles if p.is_void]
+            voids2 = [p for p in self.core_primitives.polygons if p.is_void]
+            voids.extend(voids2)
+        else:
+            voids = []
         voids_to_add = []
         for circle in voids:
             if polygonData.GetIntersectionType(circle.primitive_object.GetPolygonData()) >= 3:
                 voids_to_add.append(circle)
 
         _netsClip = convert_py_list_to_net_list(_ref_nets)
-        net_signals = List[type(_ref_nets[0])]()
+        net_signals = List[type(_ref_nets[0])]()  # pragma: no cover
         # Create new cutout cell/design
         _cutout = self.active_cell.CutOut(net_signals, _netsClip, polygonData)
         layout = _cutout.GetLayout()
-        cutout_obj_coll = layout.GetLayoutInstance().GetAllLayoutObjInstances()
+        cutout_obj_coll = list(layout.PadstackInstances)
         ids = []
-        for obj in cutout_obj_coll.Items:
-            lobj = obj.GetLayoutObj()
-            if type(lobj) is self.edb.Cell.Primitive.PadstackInstance:
-                ids.append(lobj.GetId())
+        for lobj in cutout_obj_coll:
+            ids.append(lobj.GetId())
 
         if include_partial_instances:
             p_missing = [i for i in pinstance_to_add if i.id not in ids]
@@ -1338,6 +1352,7 @@ class Edb(object):
                 self.edbpath = output_aedb_path
                 self._active_cell = cell
                 self.builder = EdbBuilder(self.edbutils, self._db, self._active_cell)
+                self.edbpath = self._db.GetDirectory()
                 self._init_objects()
             else:
                 db2.Close()
@@ -1742,7 +1757,7 @@ class Edb(object):
 
         Parameters
         ----------
-        simulation_setup : EDB_Data.SimulationConfiguratiom object.
+        simulation_setup : edb_data.SimulationConfiguratiom object.
             SimulationConfiguration object that can be instantiated or directly loaded with a
             configuration file.
 
@@ -1755,7 +1770,7 @@ class Edb(object):
         --------
 
         >>> from pyaedt import Edb
-        >>> from pyaedt.edb_core.EDB_Data import SimulationConfiguration
+        >>> from pyaedt.edb_core.edb_data.simulation_configuration import SimulationConfiguration
         >>> config_file = path_configuration_file
         >>> source_file = path_to_edb_folder
         >>> edb = Edb(source_file)
