@@ -1,6 +1,8 @@
 """This module contains the `Components` class.
 
 """
+import codecs
+import json
 import math
 import os
 import re
@@ -8,13 +10,13 @@ import warnings
 
 from pyaedt import _retry_ntimes
 from pyaedt import generate_unique_name
-from pyaedt.edb_core.EDB_Data import EDBComponent
-from pyaedt.edb_core.EDB_Data import EDBComponentDef
-from pyaedt.edb_core.EDB_Data import EDBPadstackInstance
-from pyaedt.edb_core.EDB_Data import Source
+from pyaedt.edb_core.edb_data.components_data import EDBComponent
+from pyaedt.edb_core.edb_data.components_data import EDBComponentDef
+from pyaedt.edb_core.edb_data.padstacks_data import EDBPadstackInstance
+from pyaedt.edb_core.edb_data.sources import Source
+from pyaedt.edb_core.edb_data.sources import SourceType
 from pyaedt.edb_core.general import convert_py_list_to_net_list
 from pyaedt.edb_core.padstack import EdbPadstacks
-from pyaedt.generic.constants import SourceType
 from pyaedt.generic.general_methods import get_filename_without_extension
 from pyaedt.generic.general_methods import is_ironpython
 from pyaedt.generic.general_methods import pyaedt_function_handler
@@ -73,7 +75,6 @@ class Components(object):
     def __init__(self, p_edb):
         self._pedb = p_edb
         self._cmp = {}
-        self._comp_def = {}
         self._res = {}
         self._cap = {}
         self._ind = {}
@@ -134,7 +135,7 @@ class Components(object):
 
         Returns
         -------
-        dict[str, :class:`pyaedt.edb_core.EDB_Data.EDBComponent`]
+        dict[str, :class:`pyaedt.edb_core.edb_data.components_data.EDBComponent`]
             Default dictionary for the EDB component.
 
         Examples
@@ -155,9 +156,98 @@ class Components(object):
 
         Returns
         -------
-        dict of :class:`pyaedt.edb_core.EDB_Data.EDBComponentDef`"""
+        dict of :class:`pyaedt.edb_core.edb_data.components_data.EDBComponentDef`"""
         return {l.GetName(): EDBComponentDef(self, l) for l in list(self._db.ComponentDefs)}
 
+    @property
+    def nport_comp_definition(self):
+        """Retrieve Nport component definition list."""
+        m = "Ansys.Ansoft.Edb.Definition.NPortComponentModel"
+        return {name: l for name, l in self.definitions.items() if m in [i.ToString() for i in l._comp_model]}
+
+    @pyaedt_function_handler()
+    def import_definition(self, file_path):
+        """Import component definition from json file.
+
+        Parameters
+        ----------
+        file_path : str
+            File path of json file.
+        """
+        with codecs.open(file_path, "r", encoding="utf-8") as f:
+            data = json.load(f)
+            for part_name, p in data["Definitions"].items():
+                model_type = p["Model_type"]
+                comp_definition = self.definitions[part_name]
+                comp_definition.type = p["Component_type"]
+
+                if model_type == "RLC":
+                    comp_definition.assign_rlc_model(p["Res"], p["Ind"], p["Cap"], p["Is_parallel"])
+                else:
+                    model_name = p["Model_name"]
+                    file_path = data[model_type][model_name]
+                    if model_type == "SParameterModel":
+                        if "Reference_net" in p:
+                            reference_net = p["Reference_net"]
+                        else:
+                            reference_net = None
+                        comp_definition.assign_s_param_model(file_path, model_name, reference_net)
+                    elif model_type == "SPICEModel":
+                        comp_definition.assign_spice_model(file_path, model_name)
+                    else:
+                        pass
+        return True
+
+    @pyaedt_function_handler()
+    def export_definition(self, file_path):
+        """Export component definitions to json file.
+
+        Parameters
+        ----------
+        file_path : str
+            File path of json file.
+        Returns
+        -------
+
+        """
+        data = {
+            "SParameterModel": {},
+            "SPICEModel": {},
+            "Definitions": {},
+        }
+        for part_name, props in self.definitions.items():
+            comp_list = list(props.components.values())
+            if comp_list:
+                data["Definitions"][part_name] = {}
+                data["Definitions"][part_name]["Component_type"] = props.type
+                comp = comp_list[0]
+                data["Definitions"][part_name]["Model_type"] = comp.model_type
+                if comp.model_type == "RLC":
+                    rlc_values = [i if i else 0 for i in comp.rlc_values]
+                    data["Definitions"][part_name]["Res"] = rlc_values[0]
+                    data["Definitions"][part_name]["Ind"] = rlc_values[1]
+                    data["Definitions"][part_name]["Cap"] = rlc_values[2]
+                    data["Definitions"][part_name]["Is_parallel"] = True if comp.is_parallel_rlc else False
+                else:
+                    if comp.model_type == "SParameterModel":
+                        model = comp.s_param_model
+                        data["Definitions"][part_name]["Model_name"] = model.name
+                        data["Definitions"][part_name]["Reference_net"] = model.reference_net
+                        if not model.name in data["SParameterModel"]:
+                            data["SParameterModel"][model.name] = model.file_path
+                    elif comp.model_type == "SPICEModel":
+                        model = comp.spice_model
+                        data["Definitions"][part_name]["Model_name"] = model.name
+                        if not model.name in data["SPICEModel"]:
+                            data["SPICEModel"][model.name] = model.file_path
+                    else:
+                        model = comp.netlist_model
+                        data["Definitions"][part_name]["Model_name"] = model.netlist
+
+        with codecs.open(file_path, "w", encoding="utf-8") as f:
+            json.dump(data, f, ensure_ascii=False, indent=4)
+        return file_path
+
     @pyaedt_function_handler()
     def refresh_components(self):
         """Refresh the component dictionary."""
@@ -175,7 +265,7 @@ class Components(object):
 
         Returns
         -------
-        dict[str, :class:`pyaedt.edb_core.EDB_Data.EDBComponent`]
+        dict[str, :class:`pyaedt.edb_core.edb_data.components_data.EDBComponent`]
             Dictionary of resistors.
 
         Examples
@@ -197,7 +287,7 @@ class Components(object):
 
         Returns
         -------
-        dict[str, :class:`pyaedt.edb_core.EDB_Data.EDBComponent`]
+        dict[str, :class:`pyaedt.edb_core.edb_data.components_data.EDBComponent`]
             Dictionary of capacitors.
 
         Examples
@@ -219,7 +309,7 @@ class Components(object):
 
         Returns
         -------
-        dict[str, :class:`pyaedt.edb_core.EDB_Data.EDBComponent`]
+        dict[str, :class:`pyaedt.edb_core.edb_data.components_data.EDBComponent`]
             Dictionary of inductors.
 
         Examples
@@ -242,7 +332,7 @@ class Components(object):
 
         Returns
         -------
-        dict[str, :class:`pyaedt.edb_core.EDB_Data.EDBComponent`]
+        dict[str, :class:`pyaedt.edb_core.edb_data.components_data.EDBComponent`]
             Dictionary of integrated circuits.
 
         Examples
@@ -265,7 +355,7 @@ class Components(object):
 
         Returns
         -------
-        dict[str, :class:`pyaedt.edb_core.EDB_Data.EDBComponent`]
+        dict[str, :class:`pyaedt.edb_core.edb_data.components_data.EDBComponent`]
             Dictionary of circuit inputs and outputs.
 
         Examples
@@ -291,7 +381,7 @@ class Components(object):
 
         Returns
         -------
-        dict[str, :class:`pyaedt.edb_core.EDB_Data.EDBComponent`]
+        dict[str, :class:`pyaedt.edb_core.edb_data.components_data.EDBComponent`]
             Dictionary of other core components.
 
         Examples
@@ -533,7 +623,7 @@ class Components(object):
         Parameters
         ----------
         sources : list[Source]
-            List of ``EDB_Data.Source`` objects.
+            List of ``edb_data.sources.Source`` objects.
 
         Returns
         -------
@@ -676,7 +766,6 @@ class Components(object):
         elif port_type == SourceType.CircPort:
             ref_pins = self.get_pin_from_component(component, reference_net)
             if do_pingroup:
-                pingroups = []
                 if len(ref_pins) == 1:
                     self.create_terminal = self._create_terminal(ref_pins[0])
                     self.terminal = self.create_terminal
@@ -735,7 +824,7 @@ class Components(object):
         cmp_name = pin.GetComponent().GetName()
         net_name = pin.GetNet().GetName()
         pin_name = pin.GetName()
-        term_name = "{}_{}_{}".format(cmp_name, net_name, pin_name)
+        term_name = "{}.{}.{}".format(cmp_name, net_name, pin_name)
         term = self._edb.Cell.Terminal.PointTerminal.Create(
             pin.GetLayout(), pin.GetNet(), term_name, pin_pos, from_layer
         )
@@ -890,7 +979,7 @@ class Components(object):
         layout = pingroup.GetLayout()
         cmp_name = pingroup.GetComponent().GetName()
         net_name = pingroup.GetNet().GetName()
-        term_name = generate_unique_name("Pingroup_{0}_{1}".format(cmp_name, net_name))
+        term_name = generate_unique_name("Pingroup.{0}.{1}".format(cmp_name, net_name))
         pingroup_term = self._edb.Cell.Terminal.PinGroupTerminal.Create(
             self._active_layout, pingroup.GetNet(), term_name, pingroup, isref
         )
@@ -1141,7 +1230,7 @@ class Components(object):
                 self._logger.error("Wrong number of Pins")
                 return False
 
-        elif model_type == "Touchstone":
+        elif model_type == "Touchstone":  # pragma: no cover
 
             nPortModelName = modelname
             edbComponentDef = edbComponent.GetComponentDef()
@@ -1152,12 +1241,11 @@ class Components(object):
                 edbComponentDef.AddComponentModel(nPortModel)
 
             sParameterMod = self._edb.Cell.Hierarchy.SParameterModel()
-            sParameterMod.SetComponentModelName(nPortModel)
+            sParameterMod.SetComponentModelName(nPortModelName)
             gndnets = filter(lambda x: "gnd" in x.lower(), componentNets)
-            if len(gndnets) > 0:
-
+            if len(list(gndnets)) > 0:  # pragma: no cover
                 net = gndnets[0]
-            else:
+            else:  # pragma: no cover
                 net = componentNets[len(componentNets) - 1]
             sParameterMod.SetReferenceNet(net)
             edbRlcComponentProperty.SetModel(sParameterMod)
@@ -1614,10 +1702,13 @@ class Components(object):
                         self.refresh_components()
                         comp = self.components[refdes]
 
-                comp_type = l[comp_type_col].upper()
-                comp.type = comp_type
-                print(comp.refdes, comp_type)
-                if comp_type in ["RESISTOR", "CAPACITOR", "INDUCTOR"]:
+                comp_type = l[comp_type_col]
+                if comp_type.capitalize() in ["Resistor", "Capacitor", "Inductor", "Other"]:
+                    comp.type = comp_type.capitalize()
+                else:
+                    comp.type = comp_type.upper()
+
+                if comp_type.capitalize() in ["Resistor", "Capacitor", "Inductor"] and refdes in unmount_comp_list:
                     unmount_comp_list.remove(refdes)
                 if not value_col == None:
                     try:
@@ -1625,11 +1716,11 @@ class Components(object):
                     except:
                         value = None
                     if value:
-                        if comp_type == "RESISTOR":
+                        if comp_type == "Resistor":
                             self.set_component_rlc(refdes, res_value=value)
-                        elif comp_type == "CAPACITOR":
+                        elif comp_type == "Capacitor":
                             self.set_component_rlc(refdes, cap_value=value)
-                        elif comp_type == "INDUCTOR":
+                        elif comp_type == "Inductor":
                             self.set_component_rlc(refdes, ind_value=value)
             for comp in unmount_comp_list:
                 self.components[comp].is_enabled = False
@@ -1649,15 +1740,15 @@ class Components(object):
         with open(bom_file, "w") as f:
             f.writelines([delimiter.join(["RefDes", "Part name", "Type", "Value\n"])])
             for refdes, comp in self.components.items():
-                if not comp.is_enabled and comp.type in ["RESISTOR", "CAPACITOR", "INDUCTOR"]:
+                if not comp.is_enabled and comp.type in ["Resistor", "Capacitor", "Inductor"]:
                     continue
                 part_name = comp.partname
                 comp_type = comp.type
-                if comp_type == "RESISTOR":
+                if comp_type == "Resistor":
                     value = comp.res_value
-                elif comp_type == "CAPACITOR":
+                elif comp_type == "Capacitor":
                     value = comp.cap_value
-                elif comp_type == "INDUCTOR":
+                elif comp_type == "Inductor":
                     value = comp.ind_value
                 else:
                     value = ""
@@ -1768,7 +1859,7 @@ class Components(object):
 
         Parameters
         ----------
-        pin :str
+        pin : str
             Name of the pin.
 
         Returns
