@@ -22,6 +22,22 @@ class Material(object):
         self._pclass = pclass
         self._name = edb_material_def.GetName()
         self._edb_material_def = edb_material_def
+        self._conductivity = 0.0
+        self._loss_tangent = 0.0
+        self._magnetic_loss_tangent = 0.0
+        self._mass_density = 0.0
+        self._permittivity = 0.0
+        self._permeability = 0.0
+        self._poisson_ratio = 0.0
+        self._specific_heat = 0.0
+        self._thermal_conductivity = 0.0
+        self._youngs_modulus = 0.0
+        self._thermal_expansion_coefficient = 0.0
+        self._dc_conductivity = 0.0
+        self._dc_permittivity = 0.0
+        self._dielectric_model_frequency = 0.0
+        self._loss_tangent_at_frequency = 0.0
+        self._permittivity_at_frequency = 0.0
 
     def _edb_value(self, value):
         return self._pclass._edb_value(value)
@@ -52,123 +68,270 @@ class Material(object):
     @property
     def conductivity(self):
         material_id = self._edb.Definition.MaterialPropertyId.Conductivity
-        return self._get_property(material_id)
+        self._conductivity = self._get_property(material_id)
+        return self._conductivity
 
     @conductivity.setter
     def conductivity(self, value):
         """Retrieve material conductivity."""
         material_id = self._edb.Definition.MaterialPropertyId.Conductivity
         self._edb_material_def.SetProperty(material_id, self._edb_value(value))
+        self._conductivity = value
 
     @property
     def permittivity(self):
         """Retrieve material permittivity."""
         material_id = self._edb.Definition.MaterialPropertyId.Permittivity
-        return self._get_property(material_id)
+        self._permittivity = self._get_property(material_id)
+        return self._permittivity
 
     @permittivity.setter
     def permittivity(self, value):
         material_id = self._edb.Definition.MaterialPropertyId.Permittivity
         self._edb_material_def.SetProperty(material_id, self._edb_value(value))
+        self._permittivity = value
 
     @property
     def permeability(self):
         """Retrieve material permeability."""
         material_id = self._edb.Definition.MaterialPropertyId.Permeability
-        return self._get_property(material_id)
+        self._permeability = self._get_property(material_id)
+        return self._permeability
 
     @permeability.setter
     def permeability(self, value):
         material_id = self._edb.Definition.MaterialPropertyId.Permeability
         self._edb_material_def.SetProperty(material_id, self._edb_value(value))
+        self._permeability = value
 
     @property
     def loss_tangent(self):
         """Retrieve material loss tangent."""
         material_id = self._edb.Definition.MaterialPropertyId.DielectricLossTangent
-        return self._get_property(material_id)
+        self._loss_tangent = self._get_property(material_id)
+        return self._loss_tangent
 
     @loss_tangent.setter
     def loss_tangent(self, value):
         material_id = self._edb.Definition.MaterialPropertyId.DielectricLossTangent
         self._edb_material_def.SetProperty(material_id, self._edb_value(value))
+        self._loss_tangent = value
+
+    @property
+    def dc_conductivity(self):
+        """"""
+        if self._edb_material_def.GetDielectricMaterialModel():
+            return self._edb_material_def.GetDielectricMaterialModel().GetDCConductivity()
+
+    @dc_conductivity.setter
+    def dc_conductivity(self, value):
+        if self._edb_material_def.GetDielectricMaterialModel():
+            self._edb_material_def.GetDielectricMaterialModel().SetDCConductivity(value)
+
+    @property
+    def dc_permittivity(self):
+        """"""
+        if self._edb_material_def.GetDielectricMaterialModel():
+            return self._edb_material_def.GetDielectricMaterialModel().GetDCRelativePermitivity()
+
+    @dc_permittivity.setter
+    def dc_permittivity(self, value):
+        if self._edb_material_def.GetDielectricMaterialModel():
+            self._edb_material_def.GetDielectricMaterialModel().SetDCRelativePermitivity(value)
+
+    @property
+    def dielectric_model_frequency(self):
+        """
+
+        Returns
+        -------
+        Frequency in GHz
+        """
+        if self._edb_material_def.GetDielectricMaterialModel():
+            return self._edb_material_def.GetDielectricMaterialModel().GetFrequency()
+
+    @dielectric_model_frequency.setter
+    def dielectric_model_frequency(self, value):
+        if self._edb_material_def.GetDielectricMaterialModel():
+            self._edb_material_def.GetDielectricMaterialModel().SetFrequency(value)
+
+    @property
+    def loss_tangent_at_frequency(self):
+        if self._edb_material_def.GetDielectricMaterialModel():
+            return self._edb_material_def.GetDielectricMaterialModel().GetLossTangentAtFrequency()
+
+    @loss_tangent_at_frequency.setter
+    def loss_tangent_at_frequency(self, value):
+        if self._edb_material_def.GetDielectricMaterialModel():
+            self._edb_material_def.GetDielectricMaterialModel().SetLossTangentAtFrequency(self._edb_value(value))
+
+    @property
+    def permittivity_at_frequency(self):
+        if self._edb_material_def.GetDielectricMaterialModel():
+            return self._edb_material_def.GetDielectricMaterialModel().GetRelativePermitivityAtFrequency()
+
+    @permittivity_at_frequency.setter
+    def permittivity_at_frequency(self, value):
+        if self._edb_material_def.GetDielectricMaterialModel():
+            self._edb_material_def.GetDielectricMaterialModel().SetRelativePermitivityAtFrequency(value)
 
     @property
     def magnetic_loss_tangent(self):
         """Retrieve material magnetic loss tangent."""
         material_id = self._edb.Definition.MaterialPropertyId.MagneticLossTangent
-        return self._get_property(material_id)
+        self._magnetic_loss_tangent = self._get_property(material_id)
+        return self._magnetic_loss_tangent
 
     @magnetic_loss_tangent.setter
     def magnetic_loss_tangent(self, value):
         material_id = self._edb.Definition.MaterialPropertyId.MagneticLossTangent
         self._edb_material_def.SetProperty(material_id, self._edb_value(value))
+        self._magnetic_loss_tangent = value
 
     @property
     def thermal_conductivity(self):
         """Retrieve material thermal conductivity."""
         material_id = self._edb.Definition.MaterialPropertyId.ThermalConductivity
-        return self._get_property(material_id)
+        self._thermal_conductivity = self._get_property(material_id)
+        return self._thermal_conductivity
 
     @thermal_conductivity.setter
     def thermal_conductivity(self, value):
         material_id = self._edb.Definition.MaterialPropertyId.ThermalConductivity
         self._edb_material_def.SetProperty(material_id, self._edb_value(value))
+        self._thermal_conductivity = value
 
     @property
     def mass_density(self):
         """Retrieve material mass density."""
         material_id = self._edb.Definition.MaterialPropertyId.MassDensity
-        return self._get_property(material_id)
+        self._mass_density = self._get_property(material_id)
+        return self._mass_density
 
     @mass_density.setter
     def mass_density(self, value):
         material_id = self._edb.Definition.MaterialPropertyId.MassDensity
         self._edb_material_def.SetProperty(material_id, self._edb_value(value))
+        self._mass_density = value
 
     @property
     def youngs_modulus(self):
         """Retrieve material Young's Modulus."""
         material_id = self._edb.Definition.MaterialPropertyId.YoungsModulus
-        return self._get_property(material_id)
+        self._youngs_modulus = self._get_property(material_id)
+        return self._youngs_modulus
 
     @youngs_modulus.setter
     def youngs_modulus(self, value):
         material_id = self._edb.Definition.MaterialPropertyId.YoungsModulus
         self._edb_material_def.SetProperty(material_id, self._edb_value(value))
+        self._youngs_modulus = value
 
     @property
     def specific_heat(self):
         """Retrieve material Specific Heat."""
         material_id = self._edb.Definition.MaterialPropertyId.SpecificHeat
-        return self._get_property(material_id)
+        self._specific_heat = self._get_property(material_id)
+        return self._specific_heat
 
     @specific_heat.setter
     def specific_heat(self, value):
         material_id = self._edb.Definition.MaterialPropertyId.SpecificHeat
         self._edb_material_def.SetProperty(material_id, self._edb_value(value))
+        self._specific_heat = value
 
     @property
     def poisson_ratio(self):
         """Retrieve material Poisson Ratio."""
         material_id = self._edb.Definition.MaterialPropertyId.PoissonsRatio
-        return self._get_property(material_id)
+        self._poisson_ratio = self._get_property(material_id)
+        return self._poisson_ratio
 
     @poisson_ratio.setter
     def poisson_ratio(self, value):
         material_id = self._edb.Definition.MaterialPropertyId.PoissonsRatio
         self._edb_material_def.SetProperty(material_id, self._edb_value(value))
+        self._poisson_ratio = value
 
     @property
     def thermal_expansion_coefficient(self):
         """Retrieve material Thermal Coefficient.."""
         material_id = self._edb.Definition.MaterialPropertyId.ThermalExpansionCoefficient
-        return self._get_property(material_id)
+        self._thermal_expansion_coefficient = self._get_property(material_id)
+        return self._thermal_expansion_coefficient
 
     @thermal_expansion_coefficient.setter
     def thermal_expansion_coefficient(self, value):
         material_id = self._edb.Definition.MaterialPropertyId.ThermalExpansionCoefficient
         self._edb_material_def.SetProperty(material_id, self._edb_value(value))
+        self._thermal_expansion_coefficient = value
+
+    @pyaedt_function_handler()
+    def _json_format(self):
+        out_dict = {}
+        self._name = self.name
+        self._conductivity = self.conductivity
+        self._loss_tangent = self.loss_tangent
+        self._magnetic_loss_tangent = self.magnetic_loss_tangent
+        self._mass_density = self.mass_density
+        self._permittivity = self.permittivity
+        self._permeability = self.permeability
+        self._poisson_ratio = self.poisson_ratio
+        self._specific_heat = self.specific_heat
+        self._thermal_conductivity = self.thermal_conductivity
+        self._youngs_modulus = self.youngs_modulus
+        self._thermal_expansion_coefficient = self.thermal_expansion_coefficient
+        self._dc_conductivity = self.dc_conductivity
+        self._dc_permittivity = self.dc_permittivity
+        self._dielectric_model_frequency = self.dielectric_model_frequency
+        self._loss_tangent_at_frequency = self.loss_tangent_at_frequency
+        self._permittivity_at_frequency = self.permittivity_at_frequency
+        for k, v in self.__dict__.items():
+            if not k == "_pclass" and not k == "_edb_material_def":
+                out_dict[k[1:]] = v
+        return out_dict
+
+    @pyaedt_function_handler()
+    def _load(self, input_dict):
+        if input_dict:
+            self.conductivity = input_dict["conductivity"]
+            self.loss_tangent = input_dict["loss_tangent"]
+            self.magnetic_loss_tangent = input_dict["magnetic_loss_tangent"]
+            self.mass_density = input_dict["mass_density"]
+            self.permittivity = input_dict["permittivity"]
+            self.permeability = input_dict["permeability"]
+            self.poisson_ratio = input_dict["poisson_ratio"]
+            self.specific_heat = input_dict["specific_heat"]
+            self.thermal_conductivity = input_dict["thermal_conductivity"]
+            self.youngs_modulus = input_dict["youngs_modulus"]
+            self.thermal_expansion_coefficient = input_dict["thermal_expansion_coefficient"]
+            if input_dict["dielectric_model_frequency"] is not None:
+                if self._edb_material_def.GetDielectricMaterialModel():
+                    model = self._edb_material_def.GetDielectricMaterialModel()
+                    self.dielectric_model_frequency = input_dict["dielectric_model_frequency"]
+                    self.loss_tangent_at_frequency = input_dict["loss_tangent_at_frequency"]
+                    self.permittivity_at_frequency = input_dict["permittivity_at_frequency"]
+                    if input_dict["dc_permittivity"] is not None:
+                        model.SetUseDCRelativePermitivity(True)
+                        self.dc_permittivity = input_dict["dc_permittivity"]
+                    self.dc_conductivity = input_dict["dc_conductivity"]
+                else:
+                    if not self._pclass.add_djordjevicsarkar_material(
+                        input_dict["name"],
+                        input_dict["permittivity_at_frequency"],
+                        input_dict["loss_tangent_at_frequency"],
+                        input_dict["dielectric_model_frequency"],
+                        input_dict["dc_permittivity"],
+                        input_dict["dc_conductivity"],
+                    ):
+                        self._pclass._pedb.logger.warning(
+                            'Cannot set DS model for material "{}". Check for realistic '
+                            "values that define DS Model".format(input_dict["name"])
+                        )
+            else:
+                # To unset DS model if already assigned to the material in database
+                if self._edb_material_def.GetDielectricMaterialModel():
+                    self._edb_material_def.SetDielectricMaterialModel(self._edb_value(None))
 
 
 class Materials(object):
@@ -198,8 +361,8 @@ class Materials(object):
         return {obj.GetName(): Material(self, obj) for obj in list(self._db.MaterialDefs)}
 
     @pyaedt_function_handler()
-    def add(self, name, conductivity, permittivity, loss_tangent):
-        """Add a new material in library.
+    def add_conductor_material(self, name, conductivity):
+        """Add a new conductor material in library.
 
         Parameters
         ----------
@@ -207,6 +370,26 @@ class Materials(object):
             Name of the new material.
         conductivity : float
             Conductivity of the new material.
+        -------
+
+        """
+        if not name in self.materials:
+            self._edb.Definition.MaterialDef.Create(self._db, name)
+            new_material = self.materials[name]
+            new_material.conductivity = conductivity
+            return new_material
+        else:  # pragma: no cover
+            warnings.warn("Material {} already exists in material library.".format(name))
+            return False
+
+    @pyaedt_function_handler()
+    def add_dielectric_material(self, name, permittivity, loss_tangent):
+        """Add a new dielectric material in library.
+
+        Parameters
+        ----------
+        name : str
+            Name of the new material.
         permittivity : float
             Permittivity of the new material.
         loss_tangent : float
@@ -218,7 +401,6 @@ class Materials(object):
         if not name in self.materials:
             self._edb.Definition.MaterialDef.Create(self._db, name)
             new_material = self.materials[name]
-            new_material.conductivity = conductivity
             new_material.permittivity = permittivity
             new_material.loss_tangent = loss_tangent
             return new_material
@@ -227,19 +409,41 @@ class Materials(object):
             return False
 
     @pyaedt_function_handler()
-    def add_djordjevicsarkar_material(self, name, relative_permittivity, loss_tangent, test_frequency):
+    def get_djordjevicsarkar_model(self, material_name=None):
+        """
+
+        Parameters
+        ----------
+        material_name
+
+        Returns
+        -------
+
+        """
+        material = self.materials[material_name]
+        if material:
+            return material.GetDielectricMaterialModel()
+
+    @pyaedt_function_handler()
+    def add_djordjevicsarkar_material(
+        self, name, permittivity, loss_tangent, test_frequency, dc_permittivity=None, dc_conductivity=None
+    ):
         """Create a Djordjevic_Sarkar dielectric.
 
         Parameters
         ----------
         name : str
-            Name of the dielectic.
-        relative_permittivity : float
+            Name of the dielectric.
+        permittivity : float
             Relative permittivity of the dielectric.
         loss_tangent : float
             Loss tangent for the material.
         test_frequency : float
             Test frequency in GHz for the dielectric.
+        dc_permittivity : float, optional
+            DC Relative permittivity of the dielectric.
+        dc_conductivity : float, optional
+            DC Conductivity of the dielectric.
 
         Returns
         -------
@@ -249,15 +453,20 @@ class Materials(object):
         material_def = self._edb.Definition.DjordjecvicSarkarModel()
         material_def.SetFrequency(test_frequency)
         material_def.SetLossTangentAtFrequency(self._edb_value(loss_tangent))
-        material_def.SetRelativePermitivityAtFrequency(relative_permittivity)
+        material_def.SetRelativePermitivityAtFrequency(permittivity)
+        if dc_conductivity is not None:
+            material_def.SetDCConductivity(dc_conductivity)
+        if dc_permittivity is not None:
+            material_def.SetUseDCRelativePermitivity(True)
+            material_def.SetDCRelativePermitivity(dc_permittivity)
         return self._add_dielectric_material_model(name, material_def)
 
     @pyaedt_function_handler()
     def add_debye_material(
         self,
         name,
-        relative_permittivity_low,
-        relative_permittivity_high,
+        permittivity_low,
+        permittivity_high,
         loss_tangent_low,
         loss_tangent_high,
         lower_freqency,
@@ -268,12 +477,12 @@ class Materials(object):
         Parameters
         ----------
         name : str
-            Name of the dielectic.
-        relative_permittivity_low : float
+            Name of the dielectric.
+        permittivity_low : float
             Relative permittivity of the dielectric at the frequency specified
             for ``lower_frequency``.
-        relative_permittivity_high : float
-            Relative ermittivity of the dielectric at the frequency specified
+        permittivity_high : float
+            Relative permittivity of the dielectric at the frequency specified
             for ``higher_frequency``.
         loss_tangent_low : float
             Loss tangent for the material at the frequency specified
@@ -295,7 +504,7 @@ class Materials(object):
         material_def.SetFrequencyRange(lower_freqency, higher_frequency)
         material_def.SetLossTangentAtHighLowFrequency(loss_tangent_low, loss_tangent_high)
         material_def.SetRelativePermitivityAtHighLowFrequency(
-            self._edb_value(relative_permittivity_low), self._edb_value(relative_permittivity_high)
+            self._edb_value(permittivity_low), self._edb_value(permittivity_high)
         )
         return self._add_dielectric_material_model(name, material_def)
 
@@ -304,7 +513,7 @@ class Materials(object):
         self,
         name,
         frequencies,
-        relative_permittivities,
+        permittivities,
         loss_tangents,
     ):
         """Create a dielectric with the Multipole Debye model.
@@ -312,10 +521,10 @@ class Materials(object):
         Parameters
         ----------
         name : str
-            Name of the dielectic.
+            Name of the dielectric.
         frequencies : list
             Frequencies in GHz.
-        relative_permittivities : list
+        permittivities : list
             Relative permittivities at each frequency.
         loss_tangents : list
             Loss tangents at each frequency.
@@ -335,12 +544,12 @@ class Materials(object):
         >>> diel = edb.core_stackup.create_multipole_debye_material("My_MP_Debye", freq, rel_perm, loss_tan)
         """
         frequencies = [float(i) for i in frequencies]
-        relative_permittivities = [float(i) for i in relative_permittivities]
+        permittivities = [float(i) for i in permittivities]
         loss_tangents = [float(i) for i in loss_tangents]
         material_def = self._edb.Definition.MultipoleDebyeModel()
         material_def.SetParameters(
             convert_py_list_to_net_list(frequencies),
-            convert_py_list_to_net_list(relative_permittivities),
+            convert_py_list_to_net_list(permittivities),
             convert_py_list_to_net_list(loss_tangents),
         )
         return self._add_dielectric_material_model(name, material_def)
@@ -348,11 +557,12 @@ class Materials(object):
     @pyaedt_function_handler()
     def _add_dielectric_material_model(self, name, material_model):
         if self._edb.Definition.MaterialDef.FindByName(self._db, name).IsNull():
-            DieDef = self._edb.Definition.MaterialDef.Create(self._db, name)
-            succeeded = DieDef.SetDielectricMaterialModel(material_model)
-            if succeeded:
-                return DieDef
-            return False
+            self._edb.Definition.MaterialDef.Create(self._db, name)
+        material_def = self._edb.Definition.MaterialDef.FindByName(self._db, name)
+        succeeded = material_def.SetDielectricMaterialModel(material_model)
+        if succeeded:
+            return material_def
+        return False
 
     @pyaedt_function_handler()
     def duplicate(self, material_name, new_material_name):
@@ -379,7 +589,7 @@ class Materials(object):
         >>> my_material = edb_app.core_stackup.duplicate_material("copper", "my_new_copper")
 
         """
-        if material_name in self.materials:
+        if material_name in self.materials and new_material_name not in self.materials:
             permittivity = self._edb_value(self.materials[material_name].permittivity)
             permeability = self._edb_value(self.materials[material_name].permeability)
             conductivity = self._edb_value(self.materials[material_name].conductivity)
@@ -410,3 +620,13 @@ class Materials(object):
             edb_material.SetDielectricMaterialModel(material_model)
 
             return edb_material
+
+    @pyaedt_function_handler()
+    def _load_materials(self, material=None):
+        if material:
+            if not material["name"] in self.materials:
+                if material["conductivity"] > 1e4:
+                    self.add_conductor_material(material["name"], material["conductivity"])
+                else:
+                    self.add_dielectric_material(material["name"], material["permittivity"], material["loss_tangent"])
+            self.materials[material["name"]]._load(material)
