@@ -4,8 +4,8 @@ import math
 import os
 import time
 
-from pyaedt.edb_core.EDB_Data import EDBNetsData
-from pyaedt.edb_core.EDB_Data import SimulationConfiguration
+from pyaedt.edb_core.edb_data.nets_data import EDBNetsData
+from pyaedt.edb_core.edb_data.simulation_configuration import SimulationConfiguration
 from pyaedt.generic.constants import CSS4_COLORS
 from pyaedt.generic.general_methods import generate_unique_name
 from pyaedt.generic.general_methods import is_ironpython
@@ -63,7 +63,7 @@ class EdbNets(object):
 
         Returns
         -------
-        dict[str, :class:`pyaedt.edb_core.EDB_Data.EDBNets`]
+        dict[str, :class:`pyaedt.edb_core.edb_data.nets_data.EDBNetsData`]
             Dictionary of nets.
         """
         nets = {}
@@ -77,7 +77,7 @@ class EdbNets(object):
 
         Returns
         -------
-        dict[str, :class:`pyaedt.edb_core.EDB_Data.EDBNets`]
+        dict[str, :class:`pyaedt.edb_core.edb_data.EDBNets`]
             Dictionary of signal nets.
         """
         nets = {}
@@ -92,7 +92,7 @@ class EdbNets(object):
 
         Returns
         -------
-        dict[str, :class:`pyaedt.edb_core.EDB_Data.EDBNets`]
+        dict[str, :class:`pyaedt.edb_core.edb_data.EDBNets`]
             Dictionary of power nets.
         """
         nets = {}
@@ -228,7 +228,7 @@ class EdbNets(object):
         list, str
             list of data to be used in plot.
             In case of remote session it will be returned a string that could be converted to list
-             using ast.literal_eval().
+            using ast.literal_eval().
         """
         start_time = time.time()
         color_index = 0
@@ -364,7 +364,8 @@ class EdbNets(object):
 
         Parameters
         ----------
-        simulation_configuration_object : :class:`pyaedt.edb_core.EDB_Data.SimulationConfiguration`
+        simulation_configuration_object :
+                         :class:`pyaedt.edb_core.edb_data.simulation_configuration.SimulationConfiguration`.
 
         Returns
         -------
@@ -589,15 +590,8 @@ class EdbNets(object):
             netlist = [netlist]
         nets_deleted = []
         for net in netlist:
-            try:
-                edb_net = self._edb.Cell.Net.FindByName(self._active_layout, net)
-                if edb_net is not None:
-                    edb_net.Delete()
-                    nets_deleted.append(net)
-                    self._logger.info("Net %s Deleted", net)
-            except:
-                pass
-
+            self.nets[net].delete()
+            nets_deleted.append(net)
         return nets_deleted
 
     @pyaedt_function_handler()
