@@ -6,12 +6,13 @@ This module contains the `EdbStackup` class.
 from __future__ import absolute_import  # noreorder
 
 import difflib
+import json
 import logging
 import math
 import warnings
 
-from pyaedt.edb_core.EDB_Data import EDBLayers
-from pyaedt.edb_core.EDB_Data import SimulationConfiguration
+from pyaedt.edb_core.edb_data.layer_data import EDBLayers
+from pyaedt.edb_core.edb_data.simulation_configuration import SimulationConfiguration
 from pyaedt.edb_core.general import convert_py_list_to_net_list
 from pyaedt.generic.general_methods import is_ironpython
 from pyaedt.generic.general_methods import pyaedt_function_handler
@@ -39,6 +40,23 @@ class LayerEdbClass(object):
     def __init__(self, pclass, name):
         self._pclass = pclass
         self._name = name
+        self._color = ()
+        self._type = ""
+        self._material = ""
+        self._conductivity = 0.0
+        self._permittivity = 0.0
+        self._loss_tangent = 0.0
+        self._dielectric_fill = ""
+        self._thickness = 0.0
+        self._etch_factor = 0.0
+        self._roughness_enabled = False
+        self._top_hallhuray_nodule_radius = 0.5e-6
+        self._top_hallhuray_surface_ratio = 2.9
+        self._bottom_hallhuray_nodule_radius = 0.5e-6
+        self._bottom_hallhuray_surface_ratio = 2.9
+        self._side_hallhuray_nodule_radius = 0.5e-6
+        self._side_hallhuray_surface_ratio = 2.9
+        self._material = None
 
     @property
     def _edb(self):
@@ -78,6 +96,7 @@ class LayerEdbClass(object):
         layer_clone = self._edb_layer
         layer_clone.SetColor(*rgb)
         self._pclass._set_layout_stackup(layer_clone, "change_attribute")
+        self._color = rgb
 
     @property
     def name(self):
@@ -112,8 +131,10 @@ class LayerEdbClass(object):
             return
         if new_type == "signal":
             self._edb_layer.SetLayerType(self._edb.Cell.LayerType.SignalLayer)
+            self._type = new_type
         elif new_type == "dielectric":
             self._edb_layer.SetLayerType(self._edb.Cell.LayerType.DielectricLayer)
+            self._type = new_type
         else:
             return
 
@@ -132,6 +153,7 @@ class LayerEdbClass(object):
         layer_clone = self._edb_layer
         layer_clone.SetMaterial(name)
         self._pclass._set_layout_stackup(layer_clone, "change_attribute")
+        self._material = name
 
     @property
     def conductivity(self):
@@ -142,7 +164,9 @@ class LayerEdbClass(object):
         float
         """
         if self.material in self._pclass._pedb.materials.materials:
-            return self._pclass._pedb.materials[self.material].conductivity
+            self._conductivity = self._pclass._pedb.materials[self.material].conductivity
+            return self._conductivity
+
         return None
 
     @property
@@ -154,7 +178,8 @@ class LayerEdbClass(object):
         float
         """
         if self.material in self._pclass._pedb.materials.materials:
-            return self._pclass._pedb.materials[self.material].permittivity
+            self._permittivity = self._pclass._pedb.materials[self.material].permittivity
+            return self._permittivity
         return None
 
     @property
@@ -166,14 +191,16 @@ class LayerEdbClass(object):
         float
         """
         if self.material in self._pclass._pedb.materials.materials:
-            return self._pclass._pedb.materials[self.material].loss_tangent
+            self._loss_tangent = self._pclass._pedb.materials[self.material].loss_tangent
+            return self._loss_tangent
         return None
 
     @property
     def dielectric_fill(self):
         """Retrieve material name of the layer dielectric fill."""
         if self.type == "signal":
-            return self._edb_layer.GetFillMaterial()
+            self._dielectric_fill = self._edb_layer.GetFillMaterial()
+            return self._dielectric_fill
         else:
             return
 
@@ -183,6 +210,7 @@ class LayerEdbClass(object):
             layer_clone = self._edb_layer
             layer_clone.SetFillMaterial(name)
             self._pclass._set_layout_stackup(layer_clone, "change_attribute")
+            self._dielectric_fill = name
         else:
             pass
 
@@ -196,7 +224,8 @@ class LayerEdbClass(object):
         """
         if not self.is_stackup_layer:  # pragma: no cover
             return
-        return self._edb_layer.GetThicknessValue().ToDouble()
+        self._thickness = self._edb_layer.GetThicknessValue().ToDouble()
+        return self._thickness
 
     @thickness.setter
     def thickness(self, value):
@@ -205,6 +234,7 @@ class LayerEdbClass(object):
         layer_clone = self._edb_layer
         layer_clone.SetThickness(self._pclass._edb_value(value))
         self._pclass._set_layout_stackup(layer_clone, "change_attribute")
+        self._thickness = value
 
     @property
     def etch_factor(self):
@@ -214,7 +244,8 @@ class LayerEdbClass(object):
         -------
         float
         """
-        return self._edb_layer.GetEtchFactor().ToDouble()
+        self._etch_factor = self._edb_layer.GetEtchFactor().ToDouble()
+        return self._etch_factor
 
     @etch_factor.setter
     def etch_factor(self, value):
@@ -228,6 +259,7 @@ class LayerEdbClass(object):
             layer_clone.SetEtchFactorEnabled(True)
             layer_clone.SetEtchFactor(self._pclass._edb_value(value))
         self._pclass._set_layout_stackup(layer_clone, "change_attribute")
+        self._etch_factor = value
 
     @property
     def roughness_enabled(self):
@@ -239,12 +271,14 @@ class LayerEdbClass(object):
         """
         if not self.is_stackup_layer:  # pragma: no cover
             return
-        return self._edb_layer.IsRoughnessEnabled()
+        self._roughness_enabled = self._edb_layer.IsRoughnessEnabled()
+        return self._roughness_enabled
 
     @roughness_enabled.setter
     def roughness_enabled(self, set_enable):
         if not self.is_stackup_layer:  # pragma: no cover
             return
+        self._roughness_enabled = set_enable
         if set_enable:
             layer_clone = self._edb_layer
             layer_clone.SetRoughnessEnabled(True)
@@ -255,6 +289,95 @@ class LayerEdbClass(object):
             layer_clone.SetRoughnessEnabled(False)
             self._pclass._set_layout_stackup(layer_clone, "change_attribute")
 
+    @property
+    def top_hallhuray_nodule_radius(self):
+        top_roughness_model = self.get_roughness_model("top")
+        if top_roughness_model:
+            self._top_hallhuray_nodule_radius = top_roughness_model.NoduleRadius.ToDouble()
+        return self._top_hallhuray_nodule_radius
+
+    @top_hallhuray_nodule_radius.setter
+    def top_hallhuray_nodule_radius(self, value):
+        self._top_hallhuray_nodule_radius = value
+
+    @property
+    def top_hallhuray_surface_ratio(self):
+        top_roughness_model = self.get_roughness_model("top")
+        if top_roughness_model:
+            self._top_hallhuray_surface_ratio = top_roughness_model.SurfaceRatio.ToDouble()
+        return self._top_hallhuray_surface_ratio
+
+    @top_hallhuray_surface_ratio.setter
+    def top_hallhuray_surface_ratio(self, value):
+        self._top_hallhuray_surface_ratio = value
+
+    @property
+    def bottom_hallhuray_nodule_radius(self):
+        bottom_roughness_model = self.get_roughness_model("bottom")
+        if bottom_roughness_model:
+            self._bottom_hallhuray_nodule_radius = bottom_roughness_model.NoduleRadius.ToDouble()
+        return self._bottom_hallhuray_nodule_radius
+
+    @bottom_hallhuray_nodule_radius.setter
+    def bottom_hallhuray_nodule_radius(self, value):
+        self._bottom_hallhuray_nodule_radius = value
+
+    @property
+    def bottom_hallhuray_surface_ratio(self):
+        bottom_roughness_model = self.get_roughness_model("bottom")
+        if bottom_roughness_model:
+            self._bottom_hallhuray_surface_ratio = bottom_roughness_model.SurfaceRatio.ToDouble()
+        return self._bottom_hallhuray_surface_ratio
+
+    @bottom_hallhuray_surface_ratio.setter
+    def bottom_hallhuray_surface_ratio(self, value):
+        self._bottom_hallhuray_surface_ratio = value
+
+    @property
+    def side_hallhuray_nodule_radius(self):
+        side_roughness_model = self.get_roughness_model("side")
+        if side_roughness_model:
+            self._side_hallhuray_nodule_radius = side_roughness_model.NoduleRadius.ToDouble()
+        return self._side_hallhuray_nodule_radius
+
+    @side_hallhuray_nodule_radius.setter
+    def side_hallhuray_nodule_radius(self, value):
+        self._side_hallhuray_nodule_radius = value
+
+    @property
+    def side_hallhuray_surface_ratio(self):
+        side_roughness_model = self.get_roughness_model("side")
+        if side_roughness_model:
+            self._side_hallhuray_surface_ratio = side_roughness_model.SurfaceRatio.ToDouble()
+        return self._side_hallhuray_surface_ratio
+
+    @side_hallhuray_surface_ratio.setter
+    def side_hallhuray_surface_ratio(self, value):
+        self._side_hallhuray_surface_ratio = value
+
+    @pyaedt_function_handler()
+    def get_roughness_model(self, surface="top"):
+        """Gets roughness model of the layer.
+
+        Parameters
+        ----------
+        surface : str, optional
+            Where to fetch roughness model. The default is ``"top"``. Options are ``"top"``, ``"bottom"``, ``"side"``.
+
+        Returns
+        -------
+        ``"Ansys.Ansoft.Edb.Cell.RoughnessModel"``
+
+        """
+        if not self.is_stackup_layer:  # pragma: no cover
+            return
+        if surface == "top":
+            return self._edb_layer.GetRoughnessModel(self._pclass._pedb.edb.Cell.RoughnessModel.Region.Top)
+        elif surface == "bottom":
+            return self._edb_layer.GetRoughnessModel(self._pclass._pedb.edb.Cell.RoughnessModel.Region.Bottom)
+        elif surface == "side":
+            return self._edb_layer.GetRoughnessModel(self._pclass._pedb.edb.Cell.RoughnessModel.Region.Side)
+
     @pyaedt_function_handler()
     def assign_roughness_model(
         self,
@@ -270,7 +393,7 @@ class LayerEdbClass(object):
         ----------
         model_type : str, optional
             Type of roughness model. The default is ``"huray"``. Options are ``"huray"``, ``"groisse"``.
-        huray_radius : str, optional
+        huray_radius : str, float, optional
             Radius of huray model. The default is ``"0.5um"``.
         huray_surface_ratio : str, float, optional.
             Surface ratio of huray model. The default is ``"2.9"``.
@@ -286,27 +409,27 @@ class LayerEdbClass(object):
         if not self.is_stackup_layer:  # pragma: no cover
             return
         radius = self._pclass._edb_value(huray_radius)
+        self._hurray_nodule_radius = huray_radius
         surface_ratio = self._pclass._edb_value(huray_surface_ratio)
+        self._hurray_surface_ratio = huray_surface_ratio
         groisse_roughness = self._pclass._edb_value(groisse_roughness)
         regions = []
         if apply_on_surface == "all":
+            self._side_roughness = "all"
             regions = [
                 self._pclass._pedb.edb.Cell.RoughnessModel.Region.Top,
                 self._pclass._pedb.edb.Cell.RoughnessModel.Region.Side,
                 self._pclass._pedb.edb.Cell.RoughnessModel.Region.Bottom,
             ]
         elif apply_on_surface == "top":
-            regions = [
-                self._pclass._pedb.edb.Cell.RoughnessModel.Region.Top,
-            ]
+            self._side_roughness = "top"
+            regions = [self._pclass._pedb.edb.Cell.RoughnessModel.Region.Top]
         elif apply_on_surface == "bottom":
-            regions = [
-                self._pclass._pedb.edb.Cell.RoughnessModel.Region.Bottom,
-            ]
+            self._side_roughness = "bottom"
+            regions = [self._pclass._pedb.edb.Cell.RoughnessModel.Region.Bottom]
         elif apply_on_surface == "side":
-            regions = [
-                self._pclass._pedb.edb.Cell.RoughnessModel.Region.Side,
-            ]
+            self._side_roughness = "side"
+            regions = [self._pclass._pedb.edb.Cell.RoughnessModel.Region.Side]
 
         layer_clone = self._edb_layer
         for r in regions:
@@ -317,6 +440,78 @@ class LayerEdbClass(object):
             layer_clone.SetRoughnessModel(r, model)
         return self._pclass._set_layout_stackup(layer_clone, "change_attribute")
 
+    @pyaedt_function_handler()
+    def _json_format(self):
+        dict_out = {}
+        self._color = self.color
+        self._dielectric_fill = self.dielectric_fill
+        self._etch_factor = self.etch_factor
+        self._material = self.material
+        self._name = self.name
+        self._roughness_enabled = self.roughness_enabled
+        self._thickness = self.thickness
+        self._type = self.type
+        self._roughness_enabled = self.roughness_enabled
+        self._top_hallhuray_nodule_radius = self.top_hallhuray_nodule_radius
+        self._top_hallhuray_surface_ratio = self.top_hallhuray_surface_ratio
+        self._side_hallhuray_nodule_radius = self.side_hallhuray_nodule_radius
+        self._side_hallhuray_surface_ratio = self.side_hallhuray_surface_ratio
+        self._bottom_hallhuray_nodule_radius = self.bottom_hallhuray_nodule_radius
+        self._bottom_hallhuray_surface_ratio = self.bottom_hallhuray_surface_ratio
+        for k, v in self.__dict__.items():
+            if (
+                not k == "_pclass"
+                and not k == "_conductivity"
+                and not k == "_permittivity"
+                and not k == "_loss_tangent"
+            ):
+                dict_out[k[1:]] = v
+        return dict_out
+
+    def _load_layer(self, layer):
+        if layer:
+            self.color = layer["color"]
+            self.type = layer["type"]
+            if isinstance(layer["material"], str):
+                self.material = layer["material"]
+            else:
+                self._pclass._pedb.materials._load_materials(layer["material"])
+                self.material = layer["material"]["name"]
+            if layer["dielectric_fill"]:
+                if isinstance(layer["dielectric_fill"], str):
+                    self.dielectric_fill = layer["dielectric_fill"]
+                else:
+                    self._pclass._pedb.materials._load_materials(layer["dielectric_fill"])
+                    self.dielectric_fill = layer["dielectric_fill"]["name"]
+            self.thickness = layer["thickness"]
+            self.etch_factor = layer["etch_factor"]
+            self.roughness_enabled = layer["roughness_enabled"]
+            if self.roughness_enabled:
+                self.top_hallhuray_nodule_radius = layer["top_hallhuray_nodule_radius"]
+                self.top_hallhuray_surface_ratio = layer["top_hallhuray_surface_ratio"]
+                self.assign_roughness_model(
+                    "huray",
+                    layer["top_hallhuray_nodule_radius"],
+                    layer["top_hallhuray_surface_ratio"],
+                    apply_on_surface="top",
+                )
+                self.bottom_hallhuray_nodule_radius = layer["bottom_hallhuray_nodule_radius"]
+                self.bottom_hallhuray_surface_ratio = layer["bottom_hallhuray_surface_ratio"]
+                self.assign_roughness_model(
+                    "huray",
+                    layer["bottom_hallhuray_nodule_radius"],
+                    layer["bottom_hallhuray_surface_ratio"],
+                    apply_on_surface="bottom",
+                )
+                self.side_hallhuray_nodule_radius = layer["side_hallhuray_nodule_radius"]
+                self.side_hallhuray_surface_ratio = layer["side_hallhuray_surface_ratio"]
+                self.assign_roughness_model(
+                    "huray",
+                    layer["side_hallhuray_nodule_radius"],
+                    layer["side_hallhuray_surface_ratio"],
+                    apply_on_surface="side",
+                )
+
 
 class Stackup(object):
     """Manages EDB methods for stackup accessible from `Edb.stackup` property."""
@@ -771,22 +966,68 @@ class Stackup(object):
             data["Dielectric_Fill"].append(lyr.dielectric_fill)
             data["Thickness"].append(lyr.thickness)
         df = pd.DataFrame(data, index=idx, columns=["Type", "Material", "Dielectric_Fill", "Thickness"])
-        if file_format == "csv":
+        if file_format == "csv":  # pragma: no cover
             if not fpath.endswith(".csv"):
                 fpath = fpath + ".csv"
             df.to_csv(fpath)
-        else:
-            if not fpath.endswith(".xlsx"):
+        else:  # pragma: no cover
+            if not fpath.endswith(".xlsx"):  # pragma: no cover
                 fpath = fpath + ".xlsx"
             df.to_excel(fpath)
         return True
 
+    @pyaedt_function_handler
+    def _export_layer_stackup_to_json(self, output_file=None, include_material_with_layer=False):
+        if not include_material_with_layer:
+            material_out = {}
+            for k, v in self._pedb.materials.materials.items():
+                material_out[k] = v._json_format()
+        layers_out = {}
+        for k, v in self.stackup_layers.items():
+            layers_out[k] = v._json_format()
+            if v.material in self._pedb.materials.materials:
+                layer_material = self._pedb.materials.materials[v.material]
+                if not v.dielectric_fill:
+                    dielectric_fill = False
+                else:
+                    dielectric_fill = self._pedb.materials.materials[v.dielectric_fill]
+                if include_material_with_layer:
+                    layers_out[k]["material"] = layer_material._json_format()
+                    if dielectric_fill:
+                        layers_out[k]["dielectric_fill"] = dielectric_fill._json_format()
+        if not include_material_with_layer:
+            stackup_out = {"materials": material_out, "layers": layers_out}
+        else:
+            stackup_out = {"layers": layers_out}
+        if output_file:
+            with open(output_file, "w") as write_file:
+                json.dump(stackup_out, write_file, indent=4)
+
+            return True
+        else:
+            return False
+
+    @pyaedt_function_handler()
+    def _import_layer_stackup(self, input_file=None):
+        if input_file:
+            f = open(input_file)
+            json_dict = json.load(f)  # pragma: no cover
+            for k, v in json_dict.items():
+                if k == "materials":
+                    for material in v.values():
+                        self._pedb.materials._load_materials(material)
+                if k == "layers":
+                    for layer_name, layer in v.items():
+                        if layer_name in self.stackup_layers:
+                            self.stackup_layers[layer["name"]]._load_layer(layer)
+            return True
+
 
 class EdbStackup(object):
     """Manages EDB methods for stackup and material management accessible from `Edb.core_stackup` property.
 
     .. deprecated:: 0.6.5
-    This class has been deprecated and replaced by Stackup class.
+        This class has been deprecated and replaced by the ``Stackup`` class.
 
     Examples
     --------
@@ -888,7 +1129,7 @@ class EdbStackup(object):
         Parameters
         ----------
         name : str
-            Name of the dielectic.
+            Name of the dielectric.
         permittivity : float, optional
             Permittivity of the dielectric. The default is ``1``.
         loss_tangent : float, optional
@@ -952,12 +1193,12 @@ class EdbStackup(object):
         Parameters
         ----------
         name : str
-            Name of the dielectic.
+            Name of the dielectric.
         relative_permittivity_low : float
             Relative permittivity of the dielectric at the frequency specified
             for ``lower_frequency``.
         relative_permittivity_high : float
-            Relative ermittivity of the dielectric at the frequency specified
+            Relative permittivity of the dielectric at the frequency specified
             for ``higher_frequency``.
         loss_tangent_low : float
             Loss tangent for the material at the frequency specified
@@ -1034,8 +1275,9 @@ class EdbStackup(object):
         """Return the layout thickness.
 
         Returns
-        --------
-        Float, the thickness value.
+        -------
+        float
+            The thickness value.
         """
         layers_name = list(self.stackup_layers.layers.keys())
         bottom_layer = self.stackup_layers.layers[layers_name[0]]
@@ -1489,16 +1731,18 @@ class EdbStackup(object):
         Parameters
         ----------
         a3dcomp_path : str
-            Path to 3D Component file (*.a3dcomp) to place.
+            Path to the 3D Component file (\\*.a3dcomp) to place.
         angle : double, optional
             Clockwise rotation angle applied to the a3dcomp.
         offset_x : double, optional
             The x offset value.
+            The default value is ``0.0``.
         offset_y : double, optional
             The y offset value.
+            The default value is ``0.0``.
         place_on_top : bool, optional
-            Whether to place the 3D Component on the top or bottom of this layout.
-            If False then the 3D Component will also be flipped over around its X axis.
+            Whether to place the 3D Component on the top or the bottom of this layout.
+            If ``False`` then the 3D Component will also be flipped over around its X axis.
 
         Returns
         -------
