@@ -8,6 +8,7 @@ import inspect
 import itertools
 import json
 import logging
+import math
 import os
 import random
 import re
@@ -16,6 +17,7 @@ import sys
 import tempfile
 import time
 import traceback
+import warnings
 from collections import OrderedDict
 from functools import update_wrapper
 
@@ -23,7 +25,6 @@ is_ironpython = "IronPython" in sys.version or ".NETFramework" in sys.version
 _pythonver = sys.version_info[0]
 inside_desktop = True
 main_module = sys.modules["__main__"]
-
 try:
     import ScriptEnv
 
@@ -36,6 +37,23 @@ is_remote_server = os.getenv("PYAEDT_IRONPYTHON_SERVER", "False").lower() in ("t
 if not is_ironpython:
     import psutil
 
+pd = None
+if not is_ironpython:
+    try:
+        import pandas as pd
+    except ImportError:
+        warnings.warn(
+            "The Pandas module is required to run some functionalities.\n" "Install with \n\npip install pandas\n"
+        )
+        pd = None
+    try:
+        import numpy as np
+    except ImportError:
+        warnings.warn(
+            "The NumPy module is required to run some functionalities of PostProcess.\n"
+            "Install with \n\npip install numpy\n"
+        )
+
 
 class MethodNotSupportedError(Exception):
     """ """
@@ -82,6 +100,8 @@ def _exception(ex_info, func, args, kwargs, message="Type Error"):
         messages = list(main_module.oDesktop.GetMessages("", "", 2))
     except AttributeError:
         messages = []
+    except TypeError:
+        messages = []
     if messages:
         message_to_print = messages[-1]
     for el in tblist:
@@ -106,7 +126,7 @@ def _exception(ex_info, func, args, kwargs, message="Type Error"):
     except:
         pass
 
-    _write_mes("Check Online documentation on: https://aedtdocs.pyansys.com/search.html?q={}".format(func.__name__))
+    _write_mes("Check Online documentation on: https://aedt.docs.pyansys.com/search.html?q={}".format(func.__name__))
 
 
 def _check_types(arg):
@@ -265,27 +285,39 @@ def _log_method(func, new_args, new_kwargs):
     line_begin = "    Implicit Arguments: "
     line_begin2 = "    Explicit Arguments: "
     message = []
-    if new_args:
+    delta = time.time() - settings.time_tick
+    m, s = divmod(delta, 60)
+    h, m = divmod(m, 60)
+    d, h = divmod(h, 24)
+    msec = (s - int(s)) * 1000
+    if d > 0:
+        time_msg = " {}days {}h {}m {}sec.".format(d, h, m, int(s))
+    elif h > 0:
+        time_msg = " {}h {}m {}sec.".format(h, m, int(s))
+    else:
+        time_msg = "  {}m {}sec {}msec.".format(m, int(s), int(msec))
+    if new_args and settings.enable_debug_methods_argument_logger:
         object_name = str([new_args[0]])[1:-1]
         id = object_name.find(" object at ")
         if id >= 0:
             object_name = object_name[1:id]
-            message.append(" '{}' has been exectuted.".format(object_name + "." + str(func.__name__)))
+            message.append(" '{}' has been executed in {}".format(object_name + "." + str(func.__name__), time_msg))
             if new_args[1:]:
                 message.append(line_begin + str(new_args[1:])[1:-1])
             if new_kwargs:
                 message.append(line_begin2 + str(new_kwargs)[1:-1])
 
         else:
-            message.append(" '{}' has been exectuted.".format(str(func.__name__)))
+            message.append(" '{}' has been executed in {}".format(str(func.__name__), time_msg))
             if new_args[1:]:
                 message.append(line_begin + str(new_args[1:])[1:-1])
             if new_kwargs:
                 message.append(line_begin2 + str(new_kwargs)[1:-1])
 
     else:
-        message.append(" '{}' has been exectuted".format(str(func.__name__)))
-        if new_kwargs:
+
+        message.append(" '{}' has been executed in: {}".format(str(func.__name__), time_msg))
+        if new_kwargs and settings.enable_debug_methods_argument_logger:
             message.append(line_begin2 + str(new_kwargs)[1:-1])
     for m in message:
         settings.logger.debug(m)
@@ -299,7 +331,6 @@ def pyaedt_function_handler(direct_func=None):
     and displays errors.
 
     """
-
     if callable(direct_func):
         user_function = direct_func
         wrapper = _function_handler_wrapper(user_function)
@@ -325,10 +356,11 @@ def _function_handler_wrapper(user_function):
                 converted_kwargs = _remote_dict_conversion(kwargs)
                 args = converted_args
                 kwargs = converted_kwargs
-            if settings.enable_debug_logger:
-                _log_method(user_function, args, kwargs)
             try:
+                settings.time_tick = time.time()
                 out = user_function(*args, **kwargs)
+                if settings.enable_debug_logger:
+                    _log_method(user_function, args, kwargs)
                 return out
             except TypeError:
                 if not is_remote_server:
@@ -732,6 +764,29 @@ def read_csv(filename, encoding="utf-8"):
     return lines
 
 
+@pyaedt_function_handler()
+def read_csv_pandas(filename, encoding="utf-8"):
+    """Read information from a CSV file and return a list.
+
+    Parameters
+    ----------
+    filename : str
+            Full path and name for the CSV file.
+    encoding : str, optional
+            File encoding for the CSV file. The default is ``"utf-8"``.
+
+    Returns
+    -------
+    :class:`pandas.DataFrame`
+
+    """
+    if pd:
+        return pd.read_csv(filename, encoding=encoding, header=0, na_values=".")
+    else:
+        logging.error("Pandas is not available. Install it.")
+        return None
+
+
 @pyaedt_function_handler()
 def read_tab(filename):
     """Read information from a TAB file and return a list.
@@ -766,8 +821,6 @@ def read_xlsx(filename):
 
     """
     try:
-        import pandas as pd
-
         lines = pd.read_excel(filename)
         return lines
     except:
@@ -949,6 +1002,101 @@ def grpc_active_sessions(version=None, student_version=False, non_graphical=Fals
     return sessions
 
 
+@pyaedt_function_handler()
+def compute_fft(time_vals, value):
+    """Compute FFT of input transient data.
+
+    Parameters
+    ----------
+    time_vals : `pandas.Series`
+    value : `pandas.Series`
+
+    Returns
+    -------
+    tuple
+        Frequency and Values.
+    """
+
+    deltaT = time_vals[-1] - time_vals[0]
+    num_points = len(time_vals)
+    valueFFT = np.fft.fft(value, num_points)
+    Npoints = int(len(valueFFT) / 2)
+    valueFFT = valueFFT[1 : Npoints + 1]
+    valueFFT = valueFFT / len(valueFFT)
+    n = np.arange(num_points)
+    freq = n / deltaT
+    return freq, valueFFT
+
+
+def parse_excitation_file(
+    file_name,
+    is_time_domain=True,
+    x_scale=1,
+    y_scale=1,
+    impedance=50,
+    data_format="Power",
+    encoding="utf-8",
+    out_mag="Voltage",
+):
+    """Parse a csv file and convert data in list that can be applied to Hfss and Hfss3dLayout sources.
+
+    Parameters
+    ----------
+    file_name : str
+        Full name of the input file.
+    is_time_domain : bool, optional
+        Either if the input data is Time based or Frequency Based. Frequency based data are Mag/Phase (deg).
+    x_scale : float, optional
+        Scaling factor for x axis.
+    y_scale : float, optional
+        Scaling factor for y axis.
+    data_format : str, optional
+        Either `"Power"`, `"Current"` or `"Voltage"`.
+    impedance : float, optional
+        Excitation impedance. Default is `50`.
+    encoding : str, optional
+        Csv file encoding.
+    out_mag : str, optional
+        Output magnitude format. It can be `"Voltage"` or `"Power"` depending on Hfss solution.
+
+    Returns
+    -------
+    tuple
+        Frequency, magnitude and phase.
+    """
+    df = read_csv_pandas(file_name, encoding=encoding)
+    if is_time_domain:
+        time = df[df.keys()[0]].values * x_scale
+        val = df[df.keys()[1]].values * y_scale
+        freq, fval = compute_fft(time, val)
+
+        if data_format.lower() == "current":
+            if out_mag == "Voltage":
+                fval = fval * impedance
+            else:
+                fval = fval * fval * impedance
+        elif data_format.lower() == "voltage":
+            if out_mag == "Power":
+                fval = fval * fval / impedance
+        else:
+            if out_mag == "Voltage":
+                fval = np.sqrt(fval * impedance)
+        mag = list(np.abs(fval))
+        phase = [math.atan2(j, i) * 180 / math.pi for i, j in zip(list(fval.real), list(fval.imag))]
+
+    else:
+        freq = list(df[df.keys()[0]].values * x_scale)
+        if data_format.lower() == "current":
+            mag = df[df.keys()[1]].values * df[df.keys()[1]].values * impedance * y_scale * y_scale
+        elif data_format.lower() == "voltage":
+            mag = df[df.keys()[1]].values * df[df.keys()[1]].values / impedance * y_scale * y_scale
+        else:
+            mag = df[df.keys()[1]].values * y_scale
+        mag = list(mag)
+        phase = list(df[df.keys()[2]].values)
+    return freq, mag, phase
+
+
 class PropsManager(object):
     def __getitem__(self, item):
         """Get the `self.props` key value.
@@ -1070,6 +1218,7 @@ class Settings(object):
         self._logger_formatter = "%(asctime)s:%(destination)s:%(extra)s%(levelname)-8s:%(message)s"
         self._logger_datefmt = "%Y/%m/%d %H.%M.%S"
         self._enable_debug_edb_logger = False
+        self._enable_debug_methods_argument_logger = False
         self._enable_debug_geometry_operator_logger = False
         self._enable_debug_internal_methods_logger = False
         self._enable_debug_logger = False
@@ -1089,6 +1238,67 @@ class Settings(object):
         self._disable_bounding_box_sat = False
         self._force_error_on_missing_project = False
         self._enable_pandas_output = False
+        self.time_tick = time.time()
+        self._global_log_file_name = "pyaedt_{}.log".format(os.path.split(os.path.expanduser("~"))[-1])
+        self._enable_global_log_file = True
+        self._enable_local_log_file = True
+        self._global_log_file_size = 10
+
+    @property
+    def global_log_file_size(self):
+        """Get/Set the global pyaedt log file size in Mbytes. The default value is ``10``.
+
+        Returns
+        -------
+        bool
+        """
+        return self._global_log_file_size
+
+    @global_log_file_size.setter
+    def global_log_file_size(self, value):
+        self._global_log_file_size = value
+
+    @property
+    def enable_global_log_file(self):
+        """Enable/Disable the global pyaedt log file logging in global temp folder. Default is `True`.
+
+        Returns
+        -------
+        bool
+        """
+        return self._enable_global_log_file
+
+    @enable_global_log_file.setter
+    def enable_global_log_file(self, value):
+        self._enable_global_log_file = value
+
+    @property
+    def enable_local_log_file(self):
+        """Enable/Disable the local pyaedt log file logging in projectname.pyaedt project folder. Default is `True`.
+
+        Returns
+        -------
+        bool
+        """
+        return self._enable_local_log_file
+
+    @enable_local_log_file.setter
+    def enable_local_log_file(self, value):
+        self._enable_local_log_file = value
+
+    @property
+    def global_log_file_name(self):
+        """Get/Set the global pyaedt log file path. Default is pyaedt_username.log.
+
+        Returns
+        -------
+        str
+        """
+        return self._global_log_file_name
+
+    @global_log_file_name.setter
+    def global_log_file_name(self, value):
+        self._global_log_file_name = value
 
     @property
     def enable_pandas_output(self):
@@ -1106,6 +1316,21 @@ class Settings(object):
     def enable_pandas_output(self, val):
         self._enable_pandas_output = val
 
+    @property
+    def enable_debug_methods_argument_logger(self):
+        """Set/Get a flag to plot methods argument in debug logger.
+        Default is ``False``.
+
+        Returns
+        -------
+        bool
+        """
+        return self._enable_debug_methods_argument_logger
+
+    @enable_debug_methods_argument_logger.setter
+    def enable_debug_methods_argument_logger(self, val):
+        self._enable_debug_methods_argument_logger = val
+
     @property
     def force_error_on_missing_project(self):
         """Set/Get a flag to check project path.
