@@ -255,7 +255,7 @@ class SiwaveSolve(object):
                 f.write("sourceData=[]\n")
                 f.write("proj.ScrReadDCLoopResInfo('{}', sourceNames, sourceData)\n".format(solution_name))
                 loop_res = os.path.join(output_folder, "loop_res.txt")
-                f.write("with open('{}','w') as f:\n".format(loop_res))
+                f.write("with open(r'{}','w') as f:\n".format(loop_res))
 
                 f.write("  f.writelines('Sources\tValue\\n')\n")
 
@@ -275,9 +275,9 @@ class SiwaveSolve(object):
         if hidden:
             command.append("-embedding")
         command.append("-RunScriptAndExit")
-        command.append(scriptname)
+        command.append('"' + scriptname + '"')
         print(command)
-        os.system(" ".join(command))
+        subprocess.check_output(" ".join(command))
         # p1 = subprocess.call(" ".join(command))
         # p1.wait()
         return output_list
