@@ -15,8 +15,6 @@ from pyaedt.generic.general_methods import generate_unique_name
 from pyaedt.generic.general_methods import open_file
 from pyaedt.generic.general_methods import pyaedt_function_handler
 from pyaedt.modeler.GeometryOperators import GeometryOperators
-from pyaedt.modeler.Object3d import EdgePrimitive
-from pyaedt.modeler.Object3d import FacePrimitive
 from pyaedt.modules.Boundary import BoundaryObject
 from pyaedt.modules.Boundary import MaxwellParameters
 
@@ -424,30 +422,52 @@ class Maxwell(object):
             if not activate_eddy_effects:
                 activate_displacement_current = False
             for obj in solid_objects_names:
-                if obj in object_list:
-                    EddyVector.append(
-                        [
-                            "NAME:Data",
-                            "Object Name:=",
-                            obj,
-                            "Eddy Effect:=",
-                            activate_eddy_effects,
-                            "Displacement Current:=",
-                            activate_displacement_current,
-                        ]
-                    )
-                else:
-                    EddyVector.append(
-                        [
-                            "NAME:Data",
-                            "Object Name:=",
-                            obj,
-                            "Eddy Effect:=",
-                            bool(self.oboundary.GetEddyEffect(obj)),
-                            "Displacement Current:=",
-                            bool(self.oboundary.GetDisplacementCurrent(obj)),
-                        ]
-                    )
+                if self.solution_type == "EddyCurrent":
+                    if obj in object_list:
+                        EddyVector.append(
+                            [
+                                "NAME:Data",
+                                "Object Name:=",
+                                obj,
+                                "Eddy Effect:=",
+                                activate_eddy_effects,
+                                "Displacement Current:=",
+                                activate_displacement_current,
+                            ]
+                        )
+                    else:
+                        EddyVector.append(
+                            [
+                                "NAME:Data",
+                                "Object Name:=",
+                                obj,
+                                "Eddy Effect:=",
+                                bool(self.oboundary.GetEddyEffect(obj)),
+                                "Displacement Current:=",
+                                bool(self.oboundary.GetDisplacementCurrent(obj)),
+                            ]
+                        )
+                if self.solution_type == "Transient":
+                    if obj in object_list:
+                        EddyVector.append(
+                            [
+                                "NAME:Data",
+                                "Object Name:=",
+                                obj,
+                                "Eddy Effect:=",
+                                activate_eddy_effects,
+                            ]
+                        )
+                    else:
+                        EddyVector.append(
+                            [
+                                "NAME:Data",
+                                "Object Name:=",
+                                obj,
+                                "Eddy Effect:=",
+                                bool(self.oboundary.GetEddyEffect(obj)),
+                            ]
+                        )
         else:
             for obj in solid_objects_names:
                 if obj in object_list:
@@ -616,7 +636,7 @@ class Maxwell(object):
             Object container.
         coordinate_system : str, optional
             Coordinate system name. The default is ``"Global"``.
-        axis :str or int, optional
+        axis : str or int, optional
             Coordinate system axis. The default is ``"Z"``.
             It can be a ``pyaedt.generic.constants.AXIS`` enumerator value.
         positive_movement : bool, optional
@@ -1267,30 +1287,13 @@ class Maxwell(object):
             if symmetry_name is None:
                 symmetry_name = generate_unique_name("Symmetry")
 
-            object_list = []
             if entity_list:
                 if self.design_type == "Maxwell 2D":
-                    for entity in entity_list:
-                        if isinstance(entity, EdgePrimitive):
-                            edge_id = entity.id
-                        elif isinstance(entity, int):
-                            edge_id = entity
-                        else:
-                            msg = "The input is not an edge object or an integer."
-                            raise ValueError(msg)
-                        object_list.append(edge_id)
-                    prop = OrderedDict({"Name": symmetry_name, "Edges": object_list, "IsOdd": is_odd})
+                    entity_list = self.modeler.convert_to_selections(entity_list, True)
+                    prop = OrderedDict({"Name": symmetry_name, "Edges": entity_list, "IsOdd": is_odd})
                 else:
-                    for entity in entity_list:
-                        if isinstance(entity, FacePrimitive):
-                            face_id = entity.id
-                        elif isinstance(entity, int):
-                            face_id = entity
-                        else:
-                            msg = "The input is not a valid face object or an integer."
-                            raise ValueError(msg)
-                        object_list.append(face_id)
-                    prop = OrderedDict({"Name": symmetry_name, "Faces": object_list, "IsOdd": is_odd})
+                    entity_list = self.modeler.convert_to_selections(entity_list, True)
+                    prop = OrderedDict({"Name": symmetry_name, "Faces": entity_list, "IsOdd": is_odd})
             else:
                 msg = "At least one edge must be provided."
                 ValueError(msg)
@@ -1614,13 +1617,13 @@ class Maxwell3d(Maxwell, FieldAnalysis3D, object):
 
     >>> from pyaedt import Maxwell3d
     >>> aedtapp = Maxwell3d("mymaxwell.aedt")
-    pyaedt info: Added design ...
+    pyaedt INFO: Added design ...
 
     Create an instance of Maxwell 3D using the 2021 R1 release and open
     the specified project, which is named ``mymaxwell2.aedt``.
 
     >>> aedtapp = Maxwell3d(specified_version="2021.2", projectname="mymaxwell2.aedt")
-    pyaedt info: Added design ...
+    pyaedt INFO: Added design ...
 
     """
 
