@@ -98,7 +98,15 @@ class QExtractor(FieldAnalysis3D, object):
         return self.matrices[0].sources(False)
 
     @pyaedt_function_handler()
-    def insert_reduced_matrix(self, operation_name, source_names=None, rm_name=None):
+    def insert_reduced_matrix(
+        self,
+        operation_name,
+        source_names=None,
+        rm_name=None,
+        new_net_name=None,
+        new_source_name=None,
+        new_sink_name=None,
+    ):
         """Insert a new reduced matrix.
 
         Parameters
@@ -110,6 +118,12 @@ class QExtractor(FieldAnalysis3D, object):
             is ``None``.
         rm_name : str, optional
             Name of the reduced matrix. The default is ``None``.
+        new_net_name : str, optional
+            Name of the new net. The default is ``None``.
+        new_source_name : str, optional
+            Name of the new source. The default is ``None``.
+        new_sink_name : str, optional
+            Name of the new sink. The default is ``None``.
 
         Returns
         -------
@@ -119,7 +133,17 @@ class QExtractor(FieldAnalysis3D, object):
         if not rm_name:
             rm_name = generate_unique_name(operation_name)
         matrix = Matrix(self, rm_name, operation_name)
-        if matrix.create(source_names):
+
+        if not new_net_name:
+            new_net_name = generate_unique_name("Net")
+
+        if not new_source_name:
+            new_source_name = generate_unique_name("Source")
+
+        if not new_sink_name:
+            new_sink_name = generate_unique_name("Sink")
+
+        if matrix.create(source_names, new_net_name, new_source_name, new_sink_name):
             self.matrices.append(matrix)
         return matrix
 
@@ -192,7 +216,7 @@ class QExtractor(FieldAnalysis3D, object):
 
         Parameters
         ----------
-        setup_name :str
+        setup_name : str
             Setup name.
         variation_string : str, optional
             Variation list. The default is ``""``.
@@ -398,10 +422,10 @@ class QExtractor(FieldAnalysis3D, object):
         ----------
         file_name : str
             Full path to save the matrix data to.
-            Options for file extensions are: *.m, *.lvl, *.csv, *.txt.
+            Options for file extensions are: \\*.m, \\*.lvl, \\*.csv, \\*.txt.
         problem_type : str, optional
-            Problem type. The default value is ``None``, in which case ``"C"``
-            is used. Options are ``"C"``, ``"AC RL"``, and ``"DC RL"``.
+            Problem type. The default value is ``None``, in which case ``"C"`` is
+            used. Options are ``"C"``, ``"AC RL"``, and ``"DC RL"``.
         variations : str, optional
             Design variation. The default is ``None``, in which case the
             current nominal variation is used.
@@ -435,13 +459,13 @@ class QExtractor(FieldAnalysis3D, object):
         matrix_type : str, optional
             Matrix Type.
             Possible Values are "Maxwell", "Spice" and "Couple".
-            Default value is "Maxwell, Spice, Couple".
+            The default value is ``None``.
         export_AC_DC_res : bool, optional
             Whether to add the AC and DC res.
-            Default value is ``False``.
+            The default value is ``False``.
         precision : int, optional
             Precision format.
-            Default value is ``15``.
+            The default value is ``15``.
         field_width : int, optional
             Field Width.
             The default value is ``20``.
@@ -1679,7 +1703,7 @@ class Q3d(QExtractor, object):
 
         Returns
         -------
-        SweepQ3D
+        SweepMatrix
             Sweep option.
 
         References
